/*  
 *  - - - -- - - - - - - - -
 *   g a l _ a s t r o . h
 *  - - - -- - - - - - - - -
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file defines the physical constants & macros.
 *  
 *  Status: 
 *  
 *     Library header file  
 * 
 *  Defines:
 *
 *     GAL_KM2M     Kilometers to meters
 *     GAL_AU03     Astronomical Unit IERS 2003 / DE405 meters
 *     GAL_AUR      Astronomical Unit rounded meters; Same as SOFA's December 2010 DAU
 *     GAL_AU09     Astronomical Unit IERS 2010 / IAU 2009 meters
 *     GAL_RESU76   Equatorial Radius of the Sun IAU76 meters
 *     GAL_SRP96    Solar Radiation Pressure @ 1 AU IERS 1996
 *     GAL_CMPS     Speed of Light meters per second
 *     GAL_SRS      Schwarzschild radius of the Sun (AU)
 *     GAL_RAERA00  Rate of advance of Earth rotation range IAU 2000
 *     GAL_AVEA     Mean angular velocity of the Earth
 *     GAL_AULT     Light time for 1 AU (s)
 *     GAL_CAUD     Speed of light (AU per day)
 *
 *  References:
 *
 *     The IAU 2009 system of astronomical constants: the report of the IAU
 *     working group on numerical standards for Fundamental Astronomy (2011).
 * 
 *  This revision:  
 *
 *     2013 December 20 Paul Willmott Changed to be consistent with AU09; "Defines"
 *                                    list added to comments.
 *  
 *  Revision History:
 * 
 *     2013 December 18 Paul Willmott GAL_CM renamed GAL_CMPS
 *                                    for consistency with SOFA 2013 August 27
 *                                    version.
 *  
 *  
 *     2013 August 25 Paul Willmott GAL_RAERA added.
 *  
 *     2011 July 18 Paul Willmott Some changes to the comments.
 *  
 *     2011 April 22 Paul Willmott GAL_AUR, and Speed of Light macros added.
 *  
 *     2010 April 12 Paul Willmott GAL_AU09 added.
 *  
 *     2009 February 6 Paul Willmott Baseline
 *  
 *  Copyright (C) 2009, 2010, 2011, 2012, 2013 Paul C. L. Willmott. 
 *  See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_date_macros.h"

#ifndef _GAL_ASTRO_H_  
#define _GAL_ASTRO_H_ 1  

/* 
 * Kilometers to meters
 */

#define GAL_KM2M ( 1000.0 )           

/* 
 * Astronomical Unit IERS 2003 / DE405 meters
 */

#define GAL_AU03 ( 149597870691.0 )    

/* 
 * Astronomical Unit rounded meters
 * Same as SOFA's December 2010 DAU 
 */

#define GAL_AUR ( 149597870000.0 )     

/* 
 * Astronomical Unit IERS 2010 / IAU 2009 meters
 * Adopted by IAU 2012 as a defined constant.    
 */

#define GAL_AU09 ( 149597870700.0 )    

/* 
 * Equatorial Radius of the Sun IAU76 meters
 */

#define GAL_RESU76 ( 6.96e8 )

/* 
 * Solar Radiation Pressure @ 1 AU IERS 1996
 * Newtons per meter^2
 */

#define GAL_SRP96 ( 4.56e-6 )          

/* 
 * Speed of Light meters per second
 */
                                         
#define GAL_CMPS ( 299792458.0 )       

/* 
 * Schwarzschild radius of the Sun (AU)
 */

#define GAL_SRS ( ( 2.0 * 1.32712440041e20 ) / ( GAL_CMPS * GAL_CMPS ) / GAL_AU09 ) 

/* 
 * Rate of advance of Earth rotation range IAU 2000 
 */

#define GAL_RAERA00 ( 1.00273781191135448 ) 

/*
 * Mean angular velocity of the Earth is defined in terms of the Rate of
 * advance of the Earth rotation angle (IAU 2000).
 */

#define GAL_AVEA ( GAL_RAERA00 * GAL_2PI / GAL_D2S ) 

/* 
 * Light time for 1 AU (s)
 */

#define GAL_AULT ( GAL_AU09 / GAL_CMPS ) 
                            
/* 
 * Speed of light (AU per day)
 */
 
#define GAL_CAUD ( GAL_D2S / GAL_AULT ) 

#endif /* !_GAL_ASTRO_H_ */   

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012, 2013 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
