/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ o b j e c t s . h
 *  - - - - - - - - - - - - - -
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file defines the constants for the identifier codes
 *     for the solar system objects (planets, moons, asteroids etc.)
 *
 *  Notes:
 *
 *  1) From version 0.6 GAL follows the same object numbering convention 
 *     as that of NASA's Navigation and Ancillary Information Facility 
 *     (NAIF) SPICE Toolkit. Notes in this file are derived directly 
 *     from the NAIF SPICE documentation.
 *
 *     http://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/req/index.html
 *   
 *  2) The smallest positive codes are reserved for the Sun and planetary 
 *     barycenters. For those planets without moons, Mercury and Venus, 
 *     the barycenter location coincides with the body center of mass. 
 *     However do not infer you may interchange use of the planet barycenter 
 *     ID and the planet ID. A barycenter has no radii, right ascension / 
 *     declination of the pole axis, etc. Use the planet ID when referring 
 *     to a planet or any property of that planet.
 *
 *  3) Planets have ID codes of the form P99, where P is 1, ..., 9 (the 
 *     planetary ID); a planet is always considered to be the 99th satellite 
 *     of its own barycenter, e.g. Jupiter is body number 599. Natural 
 *     satellites have ID codes of the form
 *
 *          PNN, where
 * 
 *                 P  is  1, ..., 9
 *             and NN is 01, ... 98
 *
 *     or
 *
 *          PXNNN, where
 *
 *                 P   is    1, ...,  9,
 *                 X   is    0  or    5,
 *             and NNN is  001, ... 999
 * 
 *     Codes with X = 5 are provisional.
 *
 *     e.g. Ananke, the 12th satellite of Jupiter (JXII), is body number 512. 
 *
 *  4) The SPICE convention uses negative integers as spacecraft ID codes. 
 *     The code assigned to interplanetary spacecraft is normally the 
 *     negative of the code assigned to the same spacecraft by JPL's Deep 
 *     Space Network (DSN) as determined the NASA control authority at 
 *     Goddard Space Flight Center. However, GSFC reuses the DSN codes and so
 *     these values are not unique. 
 *
 *  5)  Earth Orbiting Spacecraft. If an Earth orbiting spacecraft lacks a 
 *      DSN identification code, the NAIF ID is derived from the tracking 
 *      ID assigned to it by the US Strategic Command via:
 *
 *          NAIF ID = -100000 - US Strategic Command Object Number
 *
 *      For example US Strategic Command assigned the code 15427 to the NOAA 9 
 *      spacecraft. This code corresponds to the NAIF ID -115427. 
 *
 *  6)  ID codes for periodic comets begin at 1000001 and continue in sequence 
 *      indefinitely. (The current numbering scheme assumes that no need for 
 *      more than one million comet ID codes.) The current list of periodic 
 *      comets and their ID codes are given below. As new periodic comets are 
 *      discovered, this list will be expanded. The ID codes for a new comet 
 *      will be formed by adding one to the last comet ID in the current SPICE 
 *      list. As you can see the first portion of the list is in alphabetical 
 *      order. However, this pattern breaks down at ID code 1000112. This 
 *      reflects the fact that new periodic comets were discovered after 
 *      identification of the first 111. If you don't find the comet you are 
 *      interested in the first 111 comets listed look at the last 28 to see 
 *      if you can find the comet of interest.
 *
 *      Finally, note that Comet Shoemaker Levy 9 is included in this list 
 *      (ID code 1000130) though it is no longer a comet, periodic or otherwise. 
 *      It was an identified periodic comet prior to its breakup, which accounts 
 *      for its inclusion in this list.
 *
 *  7)  ID codes for numbered minor planets/asteroids listed in the JPL Asteroid 
 *      and Comet Catalog are determined via the algorithm:
 *
 *           NAIF ID = 2000000 + JPL Asteroid number
 *
 *      For example, asteroid Yeomans (2956) has NAIF ID number 2002956. The
 *      NAIF asteroid id codes do have a few exceptions to the above rule. 
 *      For historical reasons the minor planet Pluto is numbered as a planet 
 *      not an asteroid.
 * 
 *  Status: 
 *  
 *     Sub-library header file  
 *  
 *  Revision History:
 *
 *     2013 June 23 Paul Willmott Duplicate Identifiers removed.
 *
 *  This revision:  
 * 
 *     2011 August 1 Paul Willmott Changed to use full NAIF conventions.
 *
 *     2009 February 1 Paul Willmott Baseline
 *  
 *  Copyright (C) 2009, 2010, 2011, 2012, 2013 Paul C. L. Willmott. 
 *  See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_OBJECTS_H_  
#define _GAL_OBJECTS_H_ 1  

/*
 * ---------------------------
 * Constants NAIF Object Codes
 * ---------------------------
 */
 
enum {

/*
 * Barycenters
 * -----------
 */

/*
 * The smallest positive codes are reserved for the Sun and planetary barycenters.
 * For those planets without moons, Mercury and Venus, the barycenter location 
 * coincides with the body center of mass. However do not infer you may interchange 
 * use of the planet barycenter ID and the planet ID. A barycenter has no radii, 
 * right ascension/declination of the pole axis, etc. Use the planet ID when 
 * referring to a planet or any property of that planet.
 */      
      
  GAL_OBJ_SOLAR_SYSTEM_BARYCENTER =  0, /* Solar System Barycenter */
  GAL_OBJ_MERCURY_BARYCENTER      =  1, /* Mercury Barycenter      */
  GAL_OBJ_VENUS_BARYCENTER        =  2, /* Venus Barycenter        */
  GAL_OBJ_EARTH_MOON_BARYCENTER   =  3, /* Earth-Moon Barycenter   */
  GAL_OBJ_MARS_BARYCENTER         =  4, /* Mars Barycenter         */
  GAL_OBJ_JUPITER_BARYCENTER      =  5, /* Jupiter Barycenter      */
  GAL_OBJ_SATURN_BARYCENTER       =  6, /* Saturn Barycenter       */
  GAL_OBJ_URANUS_BARYCENTER       =  7, /* Uranus Barycenter       */
  GAL_OBJ_NEPTUNE_BARYCENTER      =  8, /* Neptune Barycenter      */
  GAL_OBJ_PLUTO_BARYCENTER        =  9, /* Pluto Barycenter        */
  GAL_OBJ_SUN                     = 10, /* Sun                     */

/*
 * Planets and Natural Satellites
 * ------------------------------
 */

/*
 * Planets have ID codes of the form P99, where P is 1, ..., 9 
 * (the planetary ID); a planet is always considered to be the 99th 
 * satellite of its own barycenter, e.g. Jupiter is body number 599. 
 * Natural satellites have ID codes of the form
 * 
 * PNN, where
 * 
 * P  is  1, ..., 9
 * and NN is 01, ... 98
 * 
 * or
 * 
 * PXNNN, where
 * 
 * P   is    1, ...,  9,
 * X   is    0  or    5,
 * and NNN is  001, ... 999
 * 
 * Codes with X = 5 are provisional.
 * 
 * e.g. Ananke, the 12th satellite of Jupiter (JXII), is body number 
 * 512. (Note the fragments of comet Shoemaker Levy 9 are exceptions 
 * to this rule.) 
 */
  
/*
 *                 NAIF ID     NAME                  IAU NUMBER
 */
 
  GAL_OBJ_MERCURY    = 199, /* MERCURY                        */	
  GAL_OBJ_VENUS      = 299, /* VENUS                          */
  GAL_OBJ_EARTH      = 399, /* EARTH                          */
  GAL_OBJ_MOON       = 301, /* MOON                           */
  GAL_OBJ_MARS       = 499, /* MARS                           */
  GAL_OBJ_PHOBOS     = 401, /* PHOBOS                MI       */	
  GAL_OBJ_DEIMOS     = 402, /* DEIMOS                MII      */	
  GAL_OBJ_JUPITER    = 599, /* JUPITER                        */
  GAL_OBJ_IO         = 501, /* IO                    JI       */	
  GAL_OBJ_EUROPA     = 502, /* EUROPA                JII      */	
  GAL_OBJ_GANYMEDE   = 503, /* GANYMEDE              JIII     */	
  GAL_OBJ_CALLISTO   = 504, /* CALLISTO              JIV      */	
  GAL_OBJ_AMALTHEA   = 505, /* AMALTHEA              JV       */	
  GAL_OBJ_HIMALIA    = 506, /* HIMALIA               JVI      */	
  GAL_OBJ_ELARA      = 507, /* ELARA                 JVII     */	
  GAL_OBJ_PASIPHAE   = 508, /* PASIPHAE              JVIII    */	
  GAL_OBJ_SINOPE     = 509, /* SINOPE                JIX      */	
  GAL_OBJ_LYSITHEA   = 510, /* LYSITHEA              JX       */	
  GAL_OBJ_CARME      = 511, /* CARME                 JXI      */	
  GAL_OBJ_ANANKE     = 512, /* ANANKE                JXII     */	
  GAL_OBJ_LEDA       = 513, /* LEDA                  JXIII    */	
  GAL_OBJ_THEBE      = 514, /* THEBE                 JXIV     */	
  GAL_OBJ_ADRASTEA   = 515, /* ADRASTEA              JXV      */	
  GAL_OBJ_METIS      = 516, /* METIS                 JXVI     */	
  GAL_OBJ_CALLIRRHOE = 517, /* CALLIRRHOE            JXVII    */	
  GAL_OBJ_THEMISTO   = 518, /* THEMISTO              JXVIII   */	
  GAL_OBJ_MAGACLITE  = 519, /* MAGACLITE             JXIX     */	
  GAL_OBJ_TAYGET     = 520, /* TAYGETE               JXX      */	
  GAL_OBJ_CHALDENE   = 521, /* CHALDENE              JXXI     */	
  GAL_OBJ_HARPALYKE  = 522, /* HARPALYKE             JXXII    */	
  GAL_OBJ_KALYKE     = 523, /* KALYKE                JXXIII   */	
  GAL_OBJ_IOCASTE    = 524, /* IOCASTE               JXXIV    */	
  GAL_OBJ_ERINOME    = 525, /* ERINOME               JXXV     */	
  GAL_OBJ_ISONOE     = 526, /* ISONOE                JXXVI    */	
  GAL_OBJ_PRAXIDIKE  = 527, /* PRAXIDIKE             JXXVII   */	
  GAL_OBJ_AUTONOE    = 528, /* AUTONOE               JXXVIII  */	
  GAL_OBJ_THYONE     = 529, /* THYONE                JXXIX    */	
  GAL_OBJ_HERMIPPE   = 530, /* HERMIPPE              JXXX     */	
  GAL_OBJ_AITNE      = 531, /* AITNE                 JXXXI    */	
  GAL_OBJ_EURYDOME   = 532, /* EURYDOME              JXXXII   */	
  GAL_OBJ_EUANTHE    = 533, /* EUANTHE               JXXXIII  */	
  GAL_OBJ_EUPORIE    = 534, /* EUPORIE               JXXXIV   */	
  GAL_OBJ_ORTHOSIE   = 535, /* ORTHOSIE              JXXXV    */	
  GAL_OBJ_SPONDE     = 536, /* SPONDE                JXXXVI   */	
  GAL_OBJ_KALE       = 537, /* KALE                  JXXXVII  */	
  GAL_OBJ_PASITHEE   = 538, /* PASITHEE              JXXXVIII */	
  GAL_OBJ_HEGEMONE   = 539, /* HEGEMONE                       */
  GAL_OBJ_MNEME      = 540, /* MNEME                          */
  GAL_OBJ_AOEDE      = 541, /* AOEDE                          */
  GAL_OBJ_THELXINOE  = 542, /* THELXINOE                      */
  GAL_OBJ_ARCHE      = 543, /* ARCHE                          */
  GAL_OBJ_KALLICHORE = 544, /* KALLICHORE                     */
  GAL_OBJ_HELIKE     = 545, /* HELIKE                         */
  GAL_OBJ_CARPO      = 546, /* CARPO                          */
  GAL_OBJ_EUKELADE   = 547, /* EUKELADE                       */
  GAL_OBJ_CYLLENE    = 548, /* CYLLENE                        */
  GAL_OBJ_KORE       = 549, /* KORE                           */
  GAL_OBJ_HERSE      = 550, /* HERSE                          */
  GAL_OBJ_SATURN     = 699, /* SATURN                         */
  GAL_OBJ_MIMAS      = 601, /* MIMAS                 SI       */	
  GAL_OBJ_ENCELADUS  = 602, /* ENCELADUS             SII      */	
  GAL_OBJ_TETHYS     = 603, /* TETHYS                SIII     */	
  GAL_OBJ_DIONE      = 604, /* DIONE                 SIV      */	
  GAL_OBJ_RHEA       = 605, /* RHEA                  SV       */	
  GAL_OBJ_TITAN      = 606, /* TITAN                 SVI      */	
  GAL_OBJ_HYPERION   = 607, /* HYPERION              SVII     */	
  GAL_OBJ_IAPETUS    = 608, /* IAPETUS               SVIII    */	
  GAL_OBJ_PHOEBE     = 609, /* PHOEBE                SIX      */	
  GAL_OBJ_JANUS      = 610, /* JANUS                 SX       */	
  GAL_OBJ_EPIMETHEUS = 611, /* EPIMETHEUS            SXI      */	
  GAL_OBJ_HELENE     = 612, /* HELENE                SXII     */	
  GAL_OBJ_TELESTO    = 613, /* TELESTO               SXIII    */	
  GAL_OBJ_CALYPSO    = 614, /* CALYPSO               SXIV     */	
  GAL_OBJ_ATLAS      = 615, /* ATLAS                 SXV      */	
  GAL_OBJ_PROMETHEUS = 616, /* PROMETHEUS            SXVI     */	
  GAL_OBJ_PANDORA    = 617, /* PANDORA               SXVII    */	
  GAL_OBJ_PAN        = 618, /* PAN                   SXVIII   */	
  GAL_OBJ_YMIR       = 619, /* YMIR                  SXIX     */	
  GAL_OBJ_PAALIAQ    = 620, /* PAALIAQ               SXX      */	
  GAL_OBJ_TARVOS     = 621, /* TARVOS                SXXI     */	
  GAL_OBJ_IJIRAQ     = 622, /* IJIRAQ                SXXII    */	
  GAL_OBJ_SUTTUNGR   = 623, /* SUTTUNGR              SXXIII   */	
  GAL_OBJ_KIVIUQ     = 624, /* KIVIUQ                SXXIV    */	
  GAL_OBJ_MUNDILFARI = 625, /* MUNDILFARI            SXXV     */	
  GAL_OBJ_ALBIORIX   = 626, /* ALBIORIX              SXXVI    */	
  GAL_OBJ_SKATHI     = 627, /* SKATHI                SXXVII   */	
  GAL_OBJ_ERRIAPUS   = 628, /* ERRIAPUS              SXXVIII  */	
  GAL_OBJ_SIARNAQ    = 629, /* SIARNAQ               SXXIX    */	
  GAL_OBJ_THRYMR     = 630, /* THRYMR                SXXX     */	
  GAL_OBJ_NARVI      = 631, /* NARVI                 SXXXI    */	
  GAL_OBJ_METHONE    = 632, /* METHONE               SXXXII   */	
  GAL_OBJ_PALLENE    = 633, /* PALLENE               SXXXIII  */	
  GAL_OBJ_POLYDEUCES = 634, /* POLYDEUCES            SXXXIV   */	
  GAL_OBJ_DAPHNIS    = 635, /* DAPHNIS                        */	
  GAL_OBJ_AEGIR      = 636, /* AEGIR                          */
  GAL_OBJ_BEBHIONN   = 637, /* BEBHIONN                       */
  GAL_OBJ_BERGELMIR  = 638, /* BERGELMIR                      */
  GAL_OBJ_BESTLA     = 639, /* BESTLA                         */
  GAL_OBJ_FARBAUTI   = 640, /* FARBAUTI                       */
  GAL_OBJ_FENRIR     = 641, /* FENRIR                         */
  GAL_OBJ_FORNJOT    = 642, /* FORNJOT                        */
  GAL_OBJ_HATI       = 643, /* HATI                           */
  GAL_OBJ_HYROKKIN   = 644, /* HYROKKIN                       */
  GAL_OBJ_KARI       = 645, /* KARI                           */
  GAL_OBJ_LOGE       = 646, /* LOGE                           */
  GAL_OBJ_SKOLL      = 647, /* SKOLL                          */
  GAL_OBJ_SURTUR     = 648, /* SURTUR                         */
  GAL_OBJ_ANTHE      = 649, /* ANTHE                          */
  GAL_OBJ_JARNSAXA   = 650, /* JARNSAXA                       */
  GAL_OBJ_GREIP      = 651, /* GREIP                          */
  GAL_OBJ_TARQEQ     = 652, /* TARQEQ                         */
  GAL_OBJ_AEGAEON    = 653, /* AEGAEON                        */
  GAL_OBJ_URANUS     = 799, /* URANUS                         */
  GAL_OBJ_ARIEL      = 701, /* ARIEL                 UI       */	
  GAL_OBJ_UMBRIEL    = 702, /* UMBRIEL               UII      */	
  GAL_OBJ_TITANIA    = 703, /* TITANIA               UIII     */	
  GAL_OBJ_OBERON     = 704, /* OBERON                UIV      */	
  GAL_OBJ_MIRANDA    = 705, /* MIRANDA               UV       */	
  GAL_OBJ_CORDELIA   = 706, /* CORDELIA              UVI      */	
  GAL_OBJ_OPHELIA    = 707, /* OPHELIA               UVII     */	
  GAL_OBJ_BIANCA     = 708, /* BIANCA                UVIII    */	
  GAL_OBJ_CRESSIDA   = 709, /* CRESSIDA              UIX      */	
  GAL_OBJ_DESDEMONA  = 710, /* DESDEMONA             UX       */	
  GAL_OBJ_JULIET     = 711, /* JULIET                UXI      */	
  GAL_OBJ_PORTIA     = 712, /* PORTIA                UXII     */	
  GAL_OBJ_ROSALIND   = 713, /* ROSALIND              UXIII    */	
  GAL_OBJ_BELINDA    = 714, /* BELINDA               UXIV     */	
  GAL_OBJ_PUCK       = 715, /* PUCK                  UXV      */	
  GAL_OBJ_CALIBAN    = 716, /* CALIBAN               UXVI     */	
  GAL_OBJ_SYCORAX    = 717, /* SYCORAX               UXVII    */	
  GAL_OBJ_PROSPERO   = 718, /* PROSPERO              UXVIII   */	
  GAL_OBJ_SETEBOS    = 719, /* SETEBOS               UXIX     */	
  GAL_OBJ_STEPHANO   = 720, /* STEPHANO              UXX      */	
  GAL_OBJ_TRINCULO   = 721, /* TRINCULO              UXXI     */	
  GAL_OBJ_FRANCISCO  = 722, /* FRANCISCO                      */ 	
  GAL_OBJ_MARGARET   = 723, /* MARGARET                       */
  GAL_OBJ_FERDINAND  = 724, /* FERDINAND                      */
  GAL_OBJ_PERDITA    = 725, /* PERDITA                        */
  GAL_OBJ_MAB        = 726, /* MAB                            */
  GAL_OBJ_CUPID      = 727, /* CUPID                          */
  GAL_OBJ_NEPTUNE    = 899, /* NEPTUNE                        */
  GAL_OBJ_TRITON     = 801, /* TRITON                NI       */	
  GAL_OBJ_NEREID     = 802, /* NEREID                NII      */	
  GAL_OBJ_NAIAD      = 803, /* NAIAD                 NIII     */	
  GAL_OBJ_THALASSA   = 804, /* THALASSA              NIV      */	
  GAL_OBJ_DESPINA    = 805, /* DESPINA               NV       */	
  GAL_OBJ_GALATEA    = 806, /* GALATEA               NVI      */	
  GAL_OBJ_LARISSA    = 807, /* LARISSA               NVII     */	
  GAL_OBJ_PROTEUS    = 808, /* PROTEUS               NVIII    */	
  GAL_OBJ_HALIMEDE   = 809, /* HALIMEDE                       */
  GAL_OBJ_PSAMATHE   = 810, /* PSAMATHE                       */
  GAL_OBJ_SAO        = 811, /* SAO                            */
  GAL_OBJ_LAOMEDEIA  = 812, /* LAOMEDEIA                      */
  GAL_OBJ_NESO       = 813, /* NESO                           */
  GAL_OBJ_PLUTO      = 999, /* PLUTO                          */
  GAL_OBJ_CHARON     = 901, /* CHARON                PI       */	
  GAL_OBJ_NIX        = 902, /* NIX                            */
  GAL_OBJ_HYDRA      = 903, /* HYDRA                          */
	
/*
 * DSN Spacecraft
 * --------------
 */

/*
 * THE SPICE convention uses negative integers as spacecraft ID codes. 
 * The code assigned to interplanetary spacecraft is normally the negative 
 * of the code assigned to the same spacecraft by JPL's Deep Space Network 
 * (DSN) as determined the NASA control authority at Goddard Space Flight Center.
 * 
 * The current SPICE vehicle code assignments:
 * 
 *                                            NAIF ID     NAME
 */
  
  GAL_OBJ_GEOTAIL                             =   -1, /* GEOTAIL                             */
  GAL_OBJ_AKATSUKI                            =   -5, /* AKATSUKI                            */
  GAL_OBJ_VCO                                 =   -5, /* VCO                                 */
  GAL_OBJ_PLANET_C                            =   -5, /* PLANET-C                            */
  GAL_OBJ_PIONEER_6                           =   -6, /* PIONEER-6                           */
  GAL_OBJ_PIONEER_7                           =   -7, /* PIONEER-7                           */
  GAL_OBJ_WIND                                =   -8, /* WIND                                */
  GAL_OBJ_VENUS_ORBITER                       =  -12, /* VENUS ORBITER                       */
  GAL_OBJ_PIONEER_12                          =  -12, /* PIONEER 12                          */
  GAL_OBJ_POLAR                               =  -13, /* POLAR                               */
  GAL_OBJ_MAGELLAN                            =  -18, /* MAGELLAN                            */
  GAL_OBJ_LCROSS                              =  -18, /* LCROSS                              */
  GAL_OBJ_PIONEER_8                           =  -20, /* PIONEER-8                           */
  GAL_OBJ_SOHO                                =  -21, /* SOHO                                */
  GAL_OBJ_PIONEER_10                          =  -23, /* PIONEER-10                          */
  GAL_OBJ_PIONEER_11                          =  -24, /* PIONEER-11                          */
  GAL_OBJ_LUNAR_PROSPECTOR                    =  -25, /* LUNAR PROSPECTOR                    */
  GAL_OBJ_VIKING_1_ORBITER                    =  -27, /* VIKING 1 ORBITER                    */
  GAL_OBJ_STARDUST                            =  -29, /* STARDUST                            */
  GAL_OBJ_SDU                                 =  -29, /* SDU                                 */
  GAL_OBJ_NEXT                                =  -29, /* NEXT                                */
  GAL_OBJ_VIKING_2_ORBITER                    =  -30, /* VIKING 2 ORBITER                    */
  GAL_OBJ_DS_1                                =  -30, /* DS-1                                */
  GAL_OBJ_VOYAGER_1                           =  -31, /* VOYAGER 1                           */
  GAL_OBJ_VOYAGER_2                           =  -32, /* VOYAGER 2                           */
  GAL_OBJ_CLEMENTINE                          =  -40, /* CLEMENTINE                          */
  GAL_OBJ_MARS_EXPRESS                        =  -41, /* MARS EXPRESS                        */
  GAL_OBJ_BEAGLE_2                            =  -44, /* BEAGLE 2                            */
  GAL_OBJ_MS_T5                               =  -46, /* MS-T5                               */
  GAL_OBJ_SAKIGAKE                            =  -46, /* SAKIGAKE                            */
  GAL_OBJ_PLANET_A                            =  -47, /* PLANET-A                            */
  GAL_OBJ_SUISEI                              =  -47, /* SUISEI                              */
  GAL_OBJ_GENESIS                             =  -47, /* GENESIS                             */
  GAL_OBJ_HUBBLE_SPACE_TELESCOPE              =  -48, /* HUBBLE SPACE TELESCOPE              */
  GAL_OBJ_MARS_PATHFINDER                     =  -53, /* MARS PATHFINDER                     */
  GAL_OBJ_MARS_ODYSSEY                        =  -53, /* MARS ODYSSEY                        */
  GAL_OBJ_MARS_SURVEYOR_1_ORBITER             =  -53, /* MARS SURVEYOR 01 ORBITER            */
  GAL_OBJ_ULYSSES                             =  -55, /* ULYSSES                             */
  GAL_OBJ_VSOP                                =  -58, /* VSOP                                */
  GAL_OBJ_HALCA                               =  -58, /* HALCA                               */
  GAL_OBJ_RADIOASTRON                         =  -59, /* RADIOASTRON                         */
  GAL_OBJ_JUNO                                =  -61, /* JUNO                                */
  GAL_OBJ_VEGA_1                              =  -66, /* VEGA 1                              */
  GAL_OBJ_VEGA_2                              =  -67, /* VEGA 2                              */
  GAL_OBJ_MERCURY_MAGNETOSPHERIC_ORBITER      =  -68, /* MERCURY MAGNETOSPHERIC ORBITER      */
  GAL_OBJ_MERCURY_PLANETARY_ORBITER           =  -69, /* MERCURY PLANETARY ORBITER           */
  GAL_OBJ_DEEP_IMPACT_IMPACTOR_SPACECRAFT     =  -70, /* DEEP IMPACT IMPACTOR SPACECRAFT     */
  GAL_OBJ_MARS_RECON_ORBITER                  =  -74, /* MARS RECON ORBITER                  */
  GAL_OBJ_MARS_SCIENCE_LABORATORY             =  -76, /* MARS SCIENCE LABORATORY             */
  GAL_OBJ_GLL                                 =  -77, /* GLL                                 */
  GAL_OBJ_GALILEO_ORBITER                     =  -77, /* GALILEO ORBITER                     */
  GAL_OBJ_GIOTTO                              =  -78, /* GIOTTO                              */
  GAL_OBJ_SPITZER                             =  -79, /* SPITZER                             */
  GAL_OBJ_SPACE_INFRARED_TELESCOPE_FACILITY   =  -79, /* SPACE INFRARED TELESCOPE FACILITY   */
  GAL_OBJ_CASSINI_ITL                         =  -81, /* CASSINI ITL                         */
  GAL_OBJ_CASSINI                             =  -82, /* CASSINI                             */
  GAL_OBJ_PHOENIX                             =  -84, /* PHOENIX                             */
  GAL_OBJ_LUNAR_RECONNAISSANCE_ORBITER        =  -85, /* LUNAR RECONNAISSANCE ORBITER        */
  GAL_OBJ_CHANDRAYAAN_1                       =  -86, /* CHANDRAYAAN-1                       */
  GAL_OBJ_CASSINI_SIMULATION                  =  -90, /* CASSINI SIMULATION                  */
  GAL_OBJ_NEAR_EARTH_ASTEROID_RENDEZVOUS      =  -93, /* NEAR EARTH ASTEROID RENDEZVOUS      */
  GAL_OBJ_MARS_OBSERVER                       =  -94, /* MARS OBSERVER                       */
  GAL_OBJ_MARS_GLOBAL_SURVEYOR                =  -94, /* MARS GLOBAL SURVEYOR                */
  GAL_OBJ_MGS_SIMULATION                      =  -95, /* MGS SIMULATION                      */
  GAL_OBJ_TOPEX_POSEIDON                      =  -97, /* TOPEX/POSEIDON                      */
  GAL_OBJ_NEW_HORIZONS                        =  -98, /* NEW HORIZONS                        */
  GAL_OBJ_TROPICAL_RAINFALL_MEASURING_MISSION = -107, /* TROPICAL RAINFALL MEASURING MISSION */
  GAL_OBJ_ICE                                 = -112, /* ICE                                 */
  GAL_OBJ_MARS_POLAR_LANDER                   = -116, /* MARS POLAR LANDER                   */
  GAL_OBJ_BEPICOLOMBO                         = -121, /* BEPICOLOMBO                         */
  GAL_OBJ_MARS_CLIMATE_ORBITER                = -127, /* MARS CLIMATE ORBITER                */
  GAL_OBJ_MUSES_C                             = -130, /* MUSES-C                             */
  GAL_OBJ_HAYABUSA                            = -130, /* HAYABUSA                            */
  GAL_OBJ_SELENE                              = -131, /* SELENE                              */
  GAL_OBJ_KAGUYA                              = -131, /* KAGUYA                              */
  GAL_OBJ_DRTS_W                              = -135, /* DRTS-W                              */
  GAL_OBJ_EPOCH                               = -140, /* EPOCH                               */
  GAL_OBJ_DIXI                                = -140, /* DIXI                                */
  GAL_OBJ_EPOXI                               = -140, /* EPOXI                               */
  GAL_OBJ_DEEP_IMPACT_FLYBY_SPACECRAFT        = -140, /* DEEP IMPACT FLYBY SPACECRAFT        */
  GAL_OBJ_TERRA                               = -142, /* TERRA                               */
  GAL_OBJ_EOS_AM1                             = -142, /* EOS-AM1                             */
  GAL_OBJ_LUNAR_A                             = -146, /* LUNAR-A                             */
  GAL_OBJ_CASSINI_PROBE                       = -150, /* CASSINI PROBE                       */
  GAL_OBJ_HUYGENS_PROBE                       = -150, /* HUYGENS PROBE                       */
  GAL_OBJ_CASP                                = -150, /* CASP                                */
  GAL_OBJ_AXAF                                = -151, /* AXAF                                */
  GAL_OBJ_CHANDRA                             = -151, /* CHANDRA                             */
  GAL_OBJ_AQUA                                = -154, /* AQUA                                */
  GAL_OBJ_EUROPA_ORBITER                      = -159, /* EUROPA ORBITER                      */
  GAL_OBJ_YOHKOH                              = -164, /* YOHKOH                              */
  GAL_OBJ_SOLAR_A                             = -164, /* SOLAR-A                             */
  GAL_OBJ_MAP                                 = -165, /* MAP                                 */
  GAL_OBJ_IMAGE                               = -166, /* IMAGE                               */
  GAL_OBJ_GRAIL_A                             = -177, /* GRAIL-A                             */
  GAL_OBJ_PLANET_B                            = -178, /* PLANET-B                            */
  GAL_OBJ_NOZOMI                              = -178, /* NOZOMI                              */ 
  GAL_OBJ_GRAIL_B                             = -181, /* GRAIL-B                             */
  GAL_OBJ_CLUSTER_1                           = -183, /* CLUSTER 1                           */
  GAL_OBJ_CLUSTER_2                           = -185, /* CLUSTER 2                           */
  GAL_OBJ_SOLAR_PROBE                         = -187, /* SOLAR PROBE                         */
  GAL_OBJ_MUSES_B                             = -188, /* MUSES-B                             */
  GAL_OBJ_SIM                                 = -190, /* SIM                                 */
  GAL_OBJ_CLUSTER_3                           = -194, /* CLUSTER 3                           */
  GAL_OBJ_CLUSTER_4                           = -196, /* CLUSTER 4                           */
  GAL_OBJ_INTEGRAL                            = -198, /* INTEGRAL                            */
  GAL_OBJ_CONTOUR                             = -200, /* CONTOUR                             */
  GAL_OBJ_MAVEN                               = -202, /* MAVEN                               */
  GAL_OBJ_DAWN                                = -203, /* DAWN                                */
  GAL_OBJ_SOIL_MOISTURE_ACTIVE_AND_PASSIVE    = -205, /* SOIL MOISTURE ACTIVE AND PASSIVE    */
  GAL_OBJ_STV51                               = -212, /* STV51                               */
  GAL_OBJ_STV52                               = -213, /* STV52                               */
  GAL_OBJ_STV53                               = -214, /* STV53                               */
  GAL_OBJ_ROSETTA                             = -226, /* ROSETTA                             */
  GAL_OBJ_KEPLER                              = -227, /* KEPLER                              */
  GAL_OBJ_GALILEO_PROBE                       = -228, /* GALILEO PROBE                       */
  GAL_OBJ_STEREO_AHEAD                        = -234, /* STEREO AHEAD                        */
  GAL_OBJ_STEREO_BEHIND                       = -235, /* STEREO BEHIND                       */
  GAL_OBJ_MESSENGER                           = -236, /* MESSENGER                           */
  GAL_OBJ_SMART_1                             = -238, /* SMART-1                             */
  GAL_OBJ_VENUS_EXPRESS                       = -248, /* VENUS EXPRESS                       */
  GAL_OBJ_OPPORTUNITY                         = -253, /* OPPORTUNITY                         */
  GAL_OBJ_MER_1                               = -253, /* MER-1                               */
  GAL_OBJ_SPIRIT                              = -254, /* SPIRIT                              */
  GAL_OBJ_MER_2                               = -254, /* MER-2                               */
  GAL_OBJ_RADIATION_BELT_STORM_PROBE_A        = -362, /* RADIATION BELT STORM PROBE A        */
  GAL_OBJ_RADIATION_BELT_STORM_PROBE_B        = -363, /* RADIATION BELT STORM PROBE B        */
  GAL_OBJ_HERSCHEL                            = -486, /* HERSCHEL                            */
  GAL_OBJ_PLANCK                              = -489, /* PLANCK                              */
  GAL_OBJ_RSAT                                = -500, /* RSAT                                */
  GAL_OBJ_SELENE_RELAY_SATELLITE              = -500, /* SELENE Relay Satellite              */
  GAL_OBJ_VSAT                                = -502, /* VSAT                                */
  GAL_OBJ_SELENE_VLBI_RADIO_SATELLITE         = -502, /* SELENE VLBI Radio Satellite         */
  GAL_OBJ_SELENE_VRAD_SATELLITE               = -502, /* SELENE VRAD Satellite               */
  GAL_OBJ_SELENE_VSTAR                        = -502, /* SELENE Vstar                        */
  GAL_OBJ_VSTAR                               = -502, /* Vstar                               */
  GAL_OBJ_MARS_96                             = -550, /* MARS-96                             */

/*
 * Earth Orbiting Spacecraft
 * -------------------------
 */ 
  
/*
 * If an Earth orbiting spacecraft lacks a DSN identification code, the 
 * NAIF ID is derived from the tracking ID assigned to it by the US Strategic 
 * Command via:
 * 
 * NAIF ID = -100000 - US Strategic Command code
 * 
 * For example US Strategic Command assigned the code 15427 to the NOAA 9 
 * spacecraft. This code corresponds to the NAIF ID -115427. 
 */
  
/*
 * Comets
 * ------
 */

/*
 * Comet Shoemaker Levy 9
 * 
 * In July, 1992 Comet Shoemaker Levy 9 passed close enough to the planet Jupiter 
 * that it was torn apart by gravitational tidal forces. As a result it became a 
 * satellite of Jupiter. However, in July 1994 the remnants of Shoemaker Levy 9 
 * collided with Jupiter. Consequently, the fragments existed as satellites of 
 * Jupiter for only two years. These fragments were given the NAIF ID's listed below. 
 * Unfortunately, there have been two competing conventions selected for identifying 
 * the fragments of the comet. In one convention the fragments have been assigned 
 * numbers 1 through 21. In the second convention the fragments have been assigned 
 * letters A through W (with I and O unused). To add to the confusion, the ordering 
 * for the numbers is reversed from the letter ordering. Fragment 21 corresponds to 
 * letter A; fragment 20 to letter B and so on. Fragment A was the first of the 
 * fragments to collide with Jupiter; fragment W was the last to collide with Jupiter.
 *   
 * The original fragments P and Q subdivided further creating the fragments P2 and Q1.
 *   
 * NAIF ID     NAME                    SHOEMAKER-LEVY 9 FRAGMENT
 *
 * 50000001    'SHOEMAKER-LEVY 9-W'    FRAGMENT 1
 * 50000002    'SHOEMAKER-LEVY 9-V'    FRAGMENT 2
 * 50000003    'SHOEMAKER-LEVY 9-U'    FRAGMENT 3
 * 50000004    'SHOEMAKER-LEVY 9-T'    FRAGMENT 4
 * 50000005    'SHOEMAKER-LEVY 9-S'    FRAGMENT 5
 * 50000006    'SHOEMAKER-LEVY 9-R'    FRAGMENT 6
 * 50000007    'SHOEMAKER-LEVY 9-Q'    FRAGMENT 7
 * 50000008    'SHOEMAKER-LEVY 9-P'    FRAGMENT 8
 * 50000009    'SHOEMAKER-LEVY 9-N'    FRAGMENT 9
 * 50000010    'SHOEMAKER-LEVY 9-M'    FRAGMENT 10
 * 50000011    'SHOEMAKER-LEVY 9-L'    FRAGMENT 11
 * 50000012    'SHOEMAKER-LEVY 9-K'    FRAGMENT 12
 * 50000013    'SHOEMAKER-LEVY 9-J'    FRAGMENT 13
 * 50000014    'SHOEMAKER-LEVY 9-H'    FRAGMENT 14
 * 50000015    'SHOEMAKER-LEVY 9-G'    FRAGMENT 15
 * 50000016    'SHOEMAKER-LEVY 9-F'    FRAGMENT 16
 * 50000017    'SHOEMAKER-LEVY 9-E'    FRAGMENT 17
 * 50000018    'SHOEMAKER-LEVY 9-D'    FRAGMENT 18
 * 50000019    'SHOEMAKER-LEVY 9-C'    FRAGMENT 19
 * 50000020    'SHOEMAKER-LEVY 9-B'    FRAGMENT 20
 * 50000021    'SHOEMAKER-LEVY 9-A'    FRAGMENT 21
 * 50000022    'SHOEMAKER-LEVY 9-Q1'   FRAGMENT 7A
 * 50000023    'SHOEMAKER-LEVY 9-P2'   FRAGMENT 8B
 */

  GAL_OBJ_SHOEMAKER_LEVY_9_W = 50000001,
  GAL_OBJ_SHOEMAKER_LEVY_9_V = 50000002,
  GAL_OBJ_SHOEMAKER_LEVY_9_U = 50000003,
  GAL_OBJ_SHOEMAKER_LEVY_9_T = 50000004,
  GAL_OBJ_SHOEMAKER_LEVY_9_S = 50000005,
  GAL_OBJ_SHOEMAKER_LEVY_9_R = 50000006,
  GAL_OBJ_SHOEMAKER_LEVY_9_Q = 50000007,
  GAL_OBJ_SHOEMAKER_LEVY_9_P = 50000008,
  GAL_OBJ_SHOEMAKER_LEVY_9_N = 50000009,
  GAL_OBJ_SHOEMAKER_LEVY_9_M = 50000010,
  GAL_OBJ_SHOEMAKER_LEVY_9_L = 50000011,
  GAL_OBJ_SHOEMAKER_LEVY_9_K = 50000012,
  GAL_OBJ_SHOEMAKER_LEVY_9_J = 50000013,
  GAL_OBJ_SHOEMAKER_LEVY_9_H = 50000014,
  GAL_OBJ_SHOEMAKER_LEVY_9_G = 50000015,
  GAL_OBJ_SHOEMAKER_LEVY_9_F = 50000016,
  GAL_OBJ_SHOEMAKER_LEVY_9_E = 50000017,
  GAL_OBJ_SHOEMAKER_LEVY_9_D = 50000018,
  GAL_OBJ_SHOEMAKER_LEVY_9_C = 50000019,
  GAL_OBJ_SHOEMAKER_LEVY_9_B = 50000020,
  GAL_OBJ_SHOEMAKER_LEVY_9_A = 50000021,
  GAL_OBJ_SHOEMAKER_LEVY_9_Q1 = 50000022,
  GAL_OBJ_SHOEMAKER_LEVY_9_P2 = 50000023,

/*
 * Periodic Comets
 */ 
  
/*
 * ID codes for periodic comets begin at 1000001 and continue in sequence 
 * indefinitely. (The current numbering scheme assumes that no need for more 
 * than one million comet ID codes.) The current list of periodic comets and 
 * their ID codes are given below. As new periodic comets are discovered, this 
 * list will be expanded. The ID codes for a new comet will be formed by 
 * adding one to the last comet ID in the current SPICE list. As you can 
 * see the first portion of the list is in alphabetical order. However, 
 * this pattern breaks down at ID code 1000112. This reflects the fact that 
 * new periodic comets were discovered after identification of the first 111. 
 * If you don't find the comet you are interested in the first 111 comets 
 * listed look at the last 28 to see if you can find the comet of interest.
 *   
 * Finally, note that Comet Shoemaker Levy 9 is included in this list 
 * (ID code 1000130) though it is no longer a comet, periodic or otherwise. 
 * It was an identified periodic comet prior to its breakup, which accounts 
 * for its inclusion in this list. 
 *
 *                                  NAIF ID     NAME
 */
 
  GAL_OBJ_AREND                   = 1000001, /* AREND                               */  
  GAL_OBJ_AREND_RIGAUX            = 1000002, /* AREND-RIGAUX                        */  
  GAL_OBJ_ASHBROOK_JACKSON        = 1000003, /* ASHBROOK-JACKSON                    */  
  GAL_OBJ_BOETHIN                 = 1000004, /* BOETHIN                             */  
  GAL_OBJ_BORRELLY                = 1000005, /* BORRELLY                            */  
  GAL_OBJ_BOWELL_SKIFF            = 1000006, /* BOWELL-SKIFF                        */  
  GAL_OBJ_BRADFIELD               = 1000007, /* BRADFIELD                           */  
  GAL_OBJ_BROOKS2                 = 1000008, /* BROOKS 2                            */  
  GAL_OBJ_BRORSEN_METCALF         = 1000009, /* BRORSEN-METCALF                     */  
  GAL_OBJ_BUS                     = 1000010, /* BUS                                 */  
  GAL_OBJ_CHERNYKH                = 1000011, /* CHERNYKH                            */  
  GAL_OBJ_CHURYUMOV_GERASIMENKO   = 1000012, /* 67P/CHURYUMOV-GERASIMENKO (1969 R1) */ 
  GAL_OBJ_CIFFREO                 = 1000013, /* CIFFREO                             */  
  GAL_OBJ_CLARK                   = 1000014, /* CLARK                               */  
  GAL_OBJ_COMAS_SOLA              = 1000015, /* COMAS SOLA                          */  
  GAL_OBJ_CROMMELIN               = 1000016, /* CROMMELIN                           */  
  GAL_OBJ_DARREST                 = 1000017, /* DARREST                             */  
  GAL_OBJ_DANIEL                  = 1000018, /* DANIEL                              */  
  GAL_OBJ_DE_VICO_SWIFT           = 1000019, /* DE VICO-SWIFT                       */  
  GAL_OBJ_DENNING_FUJIKAWA        = 1000020, /* DENNING-FUJIKAWA                    */  
  GAL_OBJ_DU_TOIT1                = 1000021, /* DU TOIT 1                           */  
  GAL_OBJ_DU_TOIT_HARTLEY         = 1000022, /* DU TOIT-HARTLEY                     */  
  GAL_OBJ_DUTOIT_NEUJMIN_DELPORTE = 1000023, /* DUTOIT-NEUJMIN-DELPORTE             */ 
  GAL_OBJ_DUBIAGO                 = 1000024, /* DUBIAGO                             */  
  GAL_OBJ_ENCKE                   = 1000025, /* ENCKE                               */  
  GAL_OBJ_FAYE                    = 1000026, /* FAYE                                */  
  GAL_OBJ_FINLAY                  = 1000027, /* FINLAY                              */  
  GAL_OBJ_FORBES                  = 1000028, /* FORBES                              */  
  GAL_OBJ_GEHRELS1                = 1000029, /* GEHRELS 1                           */  
  GAL_OBJ_GEHRELS2                = 1000030, /* GEHRELS 2                           */  
  GAL_OBJ_GEHRELS3                = 1000031, /* GEHRELS 3                           */  
  GAL_OBJ_GIACOBINI_ZINNER        = 1000032, /* GIACOBINI-ZINNER                    */  
  GAL_OBJ_GICLAS                  = 1000033, /* GICLAS                              */  
  GAL_OBJ_GRIGG_SKJELLERUP        = 1000034, /* GRIGG-SKJELLERUP                    */  
  GAL_OBJ_GUNN                    = 1000035, /* GUNN                                */  
  GAL_OBJ_HALLEY                  = 1000036, /* HALLEY                              */  
  GAL_OBJ_HANEDA_CAMPOS           = 1000037, /* HANEDA-CAMPOS                       */  
  GAL_OBJ_HARRINGTON              = 1000038, /* HARRINGTON                          */   
  GAL_OBJ_HARRINGTON_ABELL        = 1000039, /* HARRINGTON-ABELL                    */  
  GAL_OBJ_HARTLEY1                = 1000040, /* HARTLEY 1                           */  
  GAL_OBJ_HARTLEY2                = 1000041, /* HARTLEY 2                           */  
  GAL_OBJ_HARTLEY_IRAS            = 1000042, /* HARTLEY-IRAS                        */  
  GAL_OBJ_HERSCHEL_RIGOLLET       = 1000043, /* HERSCHEL-RIGOLLET                   */  
  GAL_OBJ_HOLMES                  = 1000044, /* HOLMES                              */  
  GAL_OBJ_HONDA_MRKOS_PAJDUSAKOVA = 1000045, /* HONDA-MRKOS-PAJDUSAKOVA             */ 
  GAL_OBJ_HOWELL                  = 1000046, /* HOWELL                              */  
  GAL_OBJ_IRAS                    = 1000047, /* IRAS                                */  
  GAL_OBJ_JACKSON_NEUJMIN         = 1000048, /* JACKSON-NEUJMIN                     */  
  GAL_OBJ_JOHNSON                 = 1000049, /* JOHNSON                             */  
  GAL_OBJ_KEARNS_KWEE             = 1000050, /* KEARNS-KWEE                         */  
  GAL_OBJ_KLEMOLA                 = 1000051, /* KLEMOLA                             */  
  GAL_OBJ_KOHOUTEK                = 1000052, /* KOHOUTEK                            */  
  GAL_OBJ_KOJIMA                  = 1000053, /* KOJIMA                              */  
  GAL_OBJ_KOPFF                   = 1000054, /* KOPFF                               */  
  GAL_OBJ_KOWAL1                  = 1000055, /* KOWAL 1                             */  
  GAL_OBJ_KOWAL2                  = 1000056, /* KOWAL 2                             */  
  GAL_OBJ_KOWAL_MRKOS             = 1000057, /* KOWAL-MRKOS                         */  
  GAL_OBJ_KOWAL_VAVROVA           = 1000058, /* KOWAL-VAVROVA                       */  
  GAL_OBJ_LONGMORE                = 1000059, /* LONGMORE                            */  
  GAL_OBJ_LOVAS1                  = 1000060, /* LOVAS 1                             */  
  GAL_OBJ_MACHHOLZ                = 1000061, /* MACHHOLZ                            */  
  GAL_OBJ_MAURY                   = 1000062, /* MAURY                               */  
  GAL_OBJ_NEUJMIN1                = 1000063, /* NEUJMIN 1                           */  
  GAL_OBJ_NEUJMIN2                = 1000064, /* NEUJMIN 2                           */  
  GAL_OBJ_NEUJMIN3                = 1000065, /* NEUJMIN 3                           */  
  GAL_OBJ_OLBERS                  = 1000066, /* OLBERS                              */  
  GAL_OBJ_PETERS_HARTLEY          = 1000067, /* PETERS-HARTLEY                      */  
  GAL_OBJ_PONS_BROOKS             = 1000068, /* PONS-BROOKS                         */  
  GAL_OBJ_PONS_WINNECKE           = 1000069, /* PONS-WINNECKE                       */  
  GAL_OBJ_REINMUTH1               = 1000070, /* REINMUTH 1                          */  
  GAL_OBJ_REINMUTH2               = 1000071, /* REINMUTH 2                          */  
  GAL_OBJ_RUSSELL1                = 1000072, /* RUSSELL 1                           */  
  GAL_OBJ_RUSSELL2                = 1000073, /* RUSSELL 2                           */  
  GAL_OBJ_RUSSELL3                = 1000074, /* RUSSELL 3                           */  
  GAL_OBJ_RUSSELL4                = 1000075, /* RUSSELL 4                           */  
  GAL_OBJ_SANGUIN                 = 1000076, /* SANGUIN                             */  
  GAL_OBJ_SCHAUMASSE              = 1000077, /* SCHAUMASSE                          */  
  GAL_OBJ_SCHUSTER                = 1000078, /* SCHUSTER                            */   
  GAL_OBJ_SCHWASSMANN_WACHMANN1   = 1000079, /* SCHWASSMANN-WACHMANN 1              */ 
  GAL_OBJ_SCHWASSMANN_WACHMANN2   = 1000080, /* SCHWASSMANN-WACHMANN 2              */  
  GAL_OBJ_SCHWASSMANN_WACHMANN3   = 1000081, /* SCHWASSMANN-WACHMANN 3              */  
  GAL_OBJ_SHAJN_SCHALDACH         = 1000082, /* SHAJN-SCHALDACH                     */  
  GAL_OBJ_SHOEMAKER1              = 1000083, /* SHOEMAKER 1                         */  
  GAL_OBJ_SHOEMAKER2              = 1000084, /* SHOEMAKER 2                         */  
  GAL_OBJ_SHOEMAKER3              = 1000085, /* SHOEMAKER 3                         */  
  GAL_OBJ_SINGER_BREWSTER         = 1000086, /* SINGER-BREWSTER                     */  
  GAL_OBJ_SLAUGHTER_BURNHAM       = 1000087, /* SLAUGHTER-BURNHAM                   */  
  GAL_OBJ_SMIRNOVA_CHERNYKH       = 1000088, /* SMIRNOVA-CHERNYKH                   */  
  GAL_OBJ_STEPHAN_OTERMA          = 1000089, /* STEPHAN-OTERMA                      */  
  GAL_OBJ_SWIFT_GEHRELS           = 1000090, /* SWIFT-GEHRELS                       */  
  GAL_OBJ_TAKAMIZAWA              = 1000091, /* TAKAMIZAWA                          */  
  GAL_OBJ_TAYLOR                  = 1000092, /* TAYLOR                              */  
  GAL_OBJ_TEMPEL1                 = 1000093, /* TEMPEL 1                            */  
  GAL_OBJ_TEMPEL2                 = 1000094, /* TEMPEL 2                            */  
  GAL_OBJ_TEMPEL_TUTTLE           = 1000095, /* TEMPEL-TUTTLE                       */  
  GAL_OBJ_TRITTON                 = 1000096, /* TRITTON                             */  
  GAL_OBJ_TSUCHINSHAN1            = 1000097, /* TSUCHINSHAN 1                       */  
  GAL_OBJ_TSUCHINSHAN2            = 1000098, /* TSUCHINSHAN 2                       */  
  GAL_OBJ_TUTTLE                  = 1000099, /* TUTTLE                              */  
  GAL_OBJ_TUTTLE_GIACOBINI_KRESAK = 1000100, /* TUTTLE-GIACOBINI-KRESAK             */ 
  GAL_OBJ_VAISALA1                = 1000101, /* VAISALA 1                           */  
  GAL_OBJ_VAN_BIESBROECK          = 1000102, /* VAN BIESBROECK                      */  
  GAL_OBJ_VAN_HOUTEN              = 1000103, /* VAN HOUTEN                          */  
  GAL_OBJ_WEST_KOHOUTEK_IKEMURA   = 1000104, /* WEST-KOHOUTEK-IKEMURA               */ 
  GAL_OBJ_WHIPPLE                 = 1000105, /* WHIPPLE                             */  
  GAL_OBJ_WILD1                   = 1000106, /* WILD 1                              */  
  GAL_OBJ_WILD2                   = 1000107, /* WILD 2                              */  
  GAL_OBJ_WILD3                   = 1000108, /* WILD 3                              */  
  GAL_OBJ_WIRTANEN                = 1000109, /* WIRTANEN                            */  
  GAL_OBJ_WOLF                    = 1000110, /* WOLF                                */  
  GAL_OBJ_WOLF_HARRINGTON         = 1000111, /* WOLF-HARRINGTON                     */  
  GAL_OBJ_LOVAS2                  = 1000112, /* LOVAS 2                             */  
  GAL_OBJ_URATA_NIIJIMA           = 1000113, /* URATA-NIIJIMA                       */  
  GAL_OBJ_WISEMAN_SKIFF           = 1000114, /* WISEMAN-SKIFF                       */  
  GAL_OBJ_HELIN                   = 1000115, /* HELIN                               */  
  GAL_OBJ_MUELLER                 = 1000116, /* MUELLER                             */  
  GAL_OBJ_SHOEMAKER_HOLT1         = 1000117, /* SHOEMAKER-HOLT 1                    */  
  GAL_OBJ_HELIN_ROMAN_CROCKETT    = 1000118, /* HELIN-ROMAN-CROCKETT                */  
  GAL_OBJ_HARTLEY3                = 1000119, /* HARTLEY 3                           */  
  GAL_OBJ_PARKER_HARTLEY          = 1000120, /* PARKER-HARTLEY                      */  
  GAL_OBJ_HELIN_ROMAN_ALU1        = 1000121, /* HELIN-ROMAN-ALU 1                   */  
  GAL_OBJ_WILD4                   = 1000122, /* WILD 4                              */  
  GAL_OBJ_MUELLER2                = 1000123, /* MUELLER 2                           */  
  GAL_OBJ_MUELLER3                = 1000124, /* MUELLER 3                           */  
  GAL_OBJ_SHOEMAKER_LEVY1         = 1000125, /* SHOEMAKER-LEVY 1                    */  
  GAL_OBJ_SHOEMAKER_LEVY2         = 1000126, /* SHOEMAKER-LEVY 2                    */  
  GAL_OBJ_HOLT_OLMSTEAD           = 1000127, /* HOLT-OLMSTEAD                       */  
  GAL_OBJ_METCALF_BREWINGTON      = 1000128, /* METCALF-BREWINGTON                  */  
  GAL_OBJ_LEVY                    = 1000129, /* LEVY                                */  
  GAL_OBJ_SHOEMAKER_LEVY9         = 1000130, /* SHOEMAKER-LEVY 9                    */  
  GAL_OBJ_HYAKUTAKE               = 1000131, /* HYAKUTAKE                           */  
  GAL_OBJ_HALE_BOPP               = 1000132, /* HALE-BOPP                           */  

/*
 * Asteroids
 * ---------
 */
  
/*  
 * ID codes for numbered asteroids listed in the JPL Asteroid and Comet 
 * Catalog [166.0] are determined via the algorithm:
 *   
 *  NAIF ID code = 2000000 + JPL Asteroid number
 *   
 * For example, asteroid Yeomans (2956) has NAIF ID number 2002956. The 
 * complete list of asteroids is far too numerous (over 4000 identified 
 * asteroids) to include in this document. However, we include the NAIF 
 * ID codes for the most commonly requested asteroids.
 *      
 * There are three exceptions to the rule - asteroids Gaspra, Ida and 
 * Ida's satellite Dactyl, visited by the Galileo spacecraft. The ID codes 
 * for these asteroids were determined using an older numbering convention 
 * now abandoned by the SPICE system.
 *
 * The orbit of Dactyl has not been completely determined at the time of 
 * this writing. However, in anticipation of this determination, Dactyl 
 * has been assigned the NAIF ID code 2431011.
 *
 * Note that if more than 431010 asteroids are ever identified and cataloged 
 * there will arise a conflict between the new numbering system and the 
 * ID code for Ida. At that time NAIF (or its successor) will need to add 
 * another exception to the asteroid numbering system.
 */     
      
/*
 *                            NAIF ID     NAME
 */
 
  GAL_OBJ_GASPRA            = 9511010, /* GASPRA            */
  GAL_OBJ_IDA               = 2431010, /* IDA               */
  GAL_OBJ_DACTYL            = 2431011, /* DACTYL            */
  GAL_OBJ_LUTETIA           = 2000021, /* LUTETIA           */
  GAL_OBJ_STEINS            = 2002867, /* STEINS            */
  GAL_OBJ_TOUTATIS          = 2004179, /* TOUTATIS          */
  GAL_OBJ_CERES             = 2000001, /* CERES             */ 
  GAL_OBJ_VESTA             = 2000004, /* VESTA             */ 
  GAL_OBJ_KLEOPATRA         = 2000216, /* KLEOPATRA         */ 
  GAL_OBJ_EROS              = 2000433, /* EROS              */ 
  GAL_OBJ_MATHILDE          = 2000253, /* MATHILDE          */ 
  GAL_OBJ_1992KD            = 2009969, /* 1992KD            */ 
  GAL_OBJ_BRAILLE           = 2009969, /* BRAILLE           */ 
  GAL_OBJ_WILSON_HARRINGTON = 2004015, /* WILSON-HARRINGTON */
  GAL_OBJ_ITOKAWA           = 2025143  /* ITOKAWA           */ 
} ;

#endif /* !_GAL_OBJECTS_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012, 2013 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
