/*  
 *  - - - - - - - - - - - - -
 *   g a l _ g e t p i e c e
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine finds a piece of launch in an object catalog structure.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *objcat         gal_objcat_t  Pointer to object catalog    
 *     *intldesg          char[]     International Designation of
 *                                   the piece of launch
 *  
 *  Returned:  
 *  
 *     *status         gal_status_t  Pointer to status structure
 *     *gal_getpiece   gal_piece_t   Pointer to piece of launch 
 *                                   structure, NULL if failure
 *
 *  Notes:
 *
 *  1) If the required piece of launch is not found in the object catalog
 *     then the error code GAL_NOT_FOUND is set and the routine
 *     returns NULL.
 *
 *  2) The International Designation must be in the following 
 *     format:
 *
 *          "YYYY-NNNPPP" e.g. "1997-051VX "
 *
 *  Called:
 *
 *     gal_stsinit         Initialize status structure
 *     gal_errc            Get error count
 *     gal_errset          Set error code
 *     gal_stsadd          Merge status structures
 *     gal_getlaunch       Find launch in object catalog
 *     gal_stsfree         Free status structure
 *  
 *  This revision:  
 * 
 *     2010 March 14 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 14 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>
#include "gal_getpiece.h"
#include "gal_status.h"
#include "gal_getlaunch.h"

gal_piece_t *
gal_getpiece
(
  gal_objcat_t *objcat,
  char *intldesg,
  gal_status_t *status
) 

{

  gal_launch_t *launch ;
  
  gal_piece_t *ptr ;
  
  gal_status_t *stat ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }
  
  launch = gal_getlaunch ( objcat, intldesg, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  if ( gal_errc ( status ) ) {
    gal_stsfree ( stat ) ;
    return NULL ;
  }
  
  ptr = launch->piece ;
  while ( ptr != NULL ) {
    if ( strcmp ( ptr->intldesg, intldesg ) == 0 ) {
      gal_stsfree ( stat ) ;
      return ptr ;
    }
    ptr = ptr->next ;
  }
  
  gal_stsfree ( stat ) ;
  
  gal_errset ( __FILE__, __LINE__, GAL_NOT_FOUND, status ) ;
  return NULL ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
