/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ g e t p i e c e n
 *  - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine finds a piece of launch in an object catalog structure
 *     by USSTRATCOM Object Number.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *objcat         gal_objcat_t  Pointer to object catalog    
 *     *satnum              i        USSTRATCOM Object Number of
 *                                   the piece of launch
 *  
 *  Returned:  
 *  
 *     *status         gal_status_t  Pointer to status structure
 *     *gal_getpiecen  gal_piece_t   Pointer to piece of launch 
 *                                   structure, NULL if failure
 *
 *  Notes:
 *
 *  1) If the required piece of launch is not found in the object catalog
 *     then the error code GAL_NOT_FOUND is set and the routine
 *     returns NULL.
 *
 *  2) This routine will build an index to the object catalog if
 *     one does not already exist. So the first execution will be 
 *     slower than subsequent calls.
 *
 *  Called:
 *
 *     gal_stsinit         Initialize status structure
 *     gal_errc            Get error count
 *     gal_errset          Set error code
 *     gal_stsadd          Merge status structures
 *     gal_stsfree         Free status structure
 *     gal_objcat_index    Create index for object catalog
 *  
 *  This revision:  
 * 
 *     2010 March 21 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 21 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_getpiecen.h"
#include "gal_status.h"
#include "gal_objcat_index.h"

gal_piece_t *
gal_getpiecen
(
  gal_objcat_t *objcat,
  int satnum,
  gal_status_t *status
) 

{
  gal_piece_t *ptr ;
  
  gal_status_t *stat ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }
  
/*
 * Check that index exists, if not then create it
 */
 
  if ( objcat->index == NULL ) {
    gal_objcat_index ( objcat, stat ) ;
    gal_stsadd ( stat, status ) ;
  }
  
  if ( gal_errc ( status ) ) {
    gal_stsfree ( stat ) ;
    return NULL ;
  }

/*
 * Try and find in index
 */
   
  ptr = objcat->index[satnum-1] ;
  
  if ( ptr == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_NOT_FOUND, status ) ;
  }
  
  gal_stsfree ( stat ) ;
  
  return ptr ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
