/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ i n i t s g p 4 p  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine initializes the spg4 propagator. All the initialization is
 *     consolidated here instead of having multiple loops inside other routines.
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     *gm           gal_gm_t       Pointer to gravity model structure
 *     ecco             d           Eccentricity [0.0:1.0]
 *     epoch            d           Epoch time in days from Jan 0, 1950. 0 hr
 *     inclo            d           Inclination of satellite
 *     *no              d           Mean Motion of satellite
 *  
 *  Returned:  
 *  
 *     *no              d           Mean Motion of satellite
 *     *method          c           Flag for deep space 'd', 'n'
 *     *ainv            d           1.0 / a
 *     *ao              d           Semi Major Axis
 *     *con41           d           
 *     *con42           d           1.0 - 5.0 cos(i)
 *     *cosio           d           Cosine of Inclination
 *     *cosio2          d           cosio squared
 *     *eccsq           d           Eccentricity squared
 *     *omeosq          d           1.0 - ecco * ecco
 *     *posq            d           Semi-parameter squared
 *     *rp              d           Radius of Perigee
 *     *rteosq          d           Square root of (1.0 - ecco*ecco)
 *     *sinio           d           Sine of inclination
 *     *gsto            d           GST at time of observation (rad)
 *   
 *  Called:
 *
 *     gal_sgp4gm                   Setup gravity parameters for SGP4 propagator
 *
 *  Notes:  
 *  
 *  1) This routine is a translation from c++ to c of David Vallado's SGP4UNIT.initl 
 *     routine ( 2007 November 16 ).
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980
 *     Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986
 *     Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  This revision:  
 * 
 *     2010 February 7 Paul Willmott Changed to use GAL status recording
 *                                   mechanism.
 * 
 *  Revision History:
 *
 *     2010 January 30 Paul Willmott Unused parameter satn removed.
 * 
 *     2010 January 10 Paul Willmott Missing #include "gal_sgp4gm.h" added
 *                                   Commented out code and unnecessary #include removed
 *                                   "Called" comments added.
 * 
 *     2008 April 6 Paul Willmott Baseline
 * 
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_INITSGP4P_H_  
#define _GAL_INITSGP4P_H_ 1  

#include "gal_gm.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void 
gal_initsgp4p
(
  gal_gm_t *gm,
  double ecco,   
  double epoch,  
  double inclo,   
  double *no,
  char   *method,
  double *ainv,  
  double *ao,    
  double *con41,  
  double *con42, 
  double *cosio,
  double *cosio2,
  double *eccsq, 
  double *omeosq, 
  double *posq,
  double *rp,    
  double *rteosq,
  double *sinio , 
  double *gsto,
  gal_status_t *status
) ;
  
__END_DECLS  
  
#endif /* !_GAL_INITSGP4P_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
