/*  
 *  - - - - - - - - - - - - - - -
 *   g a l _ l a u n c h _ i n s
 *  - - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine inserts a launch into an object catalog.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *objcat           gal_objcat_t  Pointer to object catalog
 *     year                    i       Year of launch
 *     number                  i       Launch number of year
 *
 *  Returned:  
 *  
 *     *status           gal_status_t  Pointer to status structure
 *     *gal_launch_ins   gal_launch_t  Pointer to launch 
 *                                     structure, NULL if failure
 * 
 *  Notes:
 *
 *  1) If the launch is already in the catalog then a pointer
 *     is returned to the existing structure. i.e. no duplicates
 *     are created.
 *
 *  2) If an internal error occurs then the error code
 *     GAL_ALLOC_FAILED is set and the routine returns NULL.
 *
 *  3) The launches are stored in a linked list within the
 *     catalog, the order is most recent first.
 * 
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include <string.h>
#include "gal_launch_ins.h"
#include "gal_status.h"

gal_launch_t *
gal_launch_ins
(
  gal_objcat_t *objcat,
  int          year,
  int          number,
  gal_status_t *status
) 

{

  gal_launch_t *ptr, *lptr ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
/*
 * Check for valid object catalog
 */
 
  if ( objcat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return NULL ;
  }

/*
 * --------------------
 * Find insertion point
 * --------------------
 */

/*
 * Handle empty list case
 */
 
  if ( objcat->launch == NULL ) {
  
    if ( ( ptr = ( gal_launch_t * ) malloc ( sizeof ( gal_launch_t ) ) ) == NULL ) {
      gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
      return NULL ;
    }
    
    objcat->launch = ptr ;
    ptr->next = NULL ;
    
  }
  else {
  
/*
 * Handle First case equal
 */
   
    ptr = objcat->launch ;
    
    if ( ptr->year == year && ptr->number == number ) {
      return ptr ;
    }

    else {
  
/*
 * Handle first case insert
 */
 
      if ( ptr->year < year || ( ptr->year == year && ptr->number < number ) ) {
    
        if ( ( ptr = ( gal_launch_t * ) malloc ( sizeof ( gal_launch_t ) ) ) == NULL ) {
          gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
          return NULL ;
        }
      
        ptr->next = objcat->launch ;
        objcat->launch = ptr ;
      
      }
      else {
      
/*
 * Handle generic cases
 */
     
        while ( ptr->next != NULL &&  ( ptr->next->year > year || ( ptr->next->year == year && ptr->next->number > number ) ) ) {
          ptr = ptr->next ;
        }
    
        if ( ptr->next != NULL && ptr->next->year == year && ptr->next->number == number ) {
          return ptr->next ;
        }
    
        lptr = ptr ;
  
        if ( ( ptr = ( gal_launch_t * ) malloc ( sizeof ( gal_launch_t ) ) ) == NULL ) {
          gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
          return NULL ;
        }
    
        ptr->next = lptr->next ;
        lptr->next = ptr ;
      
      }
    
    }
    
  }
  
/*
 * Common stuff
 */
 
  ptr->year = year ;
  ptr->number = number ;
  ptr->launch_date1 = 0.0 ;
  ptr->launch_date2 = 0.0 ;
  ptr->lv_code = GAL_LV_UNKNOWN ;
  ptr->piece = NULL ;
  ptr->pcount = 0 ;
  
  return ptr ;
      
/*  
 * Finished.  
 */  
  
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
