/*  
 *  - - - - - - - - - -
 *   g a l _ l d s s r 
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine loads an object catalog from a US Strategic
 *     Command Satellite Situation Report file.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file
 *
 *
 *  Returned:  
 *  
 *     *objcat      gal_objcat_t      Pointer to object catalog
 *     *status      gal_status_t      Pointer to status structure
 * 
 *  Notes:
 *
 *  1)  The Satellite Situation Report is a listing of those satellites
 *      (objects) currently in orbit and those which have previously 
 *      orbited the Earth. Some objects are too small or too far from 
 *      the Earth's surface to be detected; therefore, the Satellite 
 *      Situation Report does not include all man-made objects orbiting 
 *      the Earth.
 *
 *  2)  The latest report can be downloaded from here:
 *
 *      http://www.space-track.org/perl/login.pl
 *
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsfree           Free status structure
 *     gal_sseek             Seek for a string in a file     
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_trim              Trim whitespace from string ends
 *     gal_fscan             Decode FORTRAN style string
 *     gal_piece_ins         Add piece of launch to object catalog
 *     gal_instr             Search for substring in string
 *     gal_cal2jd            Calendar date to Julian Date
 *     gal_lvcode            Get launch vehicle code
 *     gal_objowner_code     Get Catalog Object Owner Code
 *     gal_getlaunch         Find launch in object catalog
 *
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "gal_ldssr.h"
#include "gal_status.h"
#include "gal_pstrings.h"
#include "gal_objcat_init.h"
#include "gal_cal2jd.h"
#include "gal_piece_ins.h"
#include "gal_lvcode.h"
#include "gal_objowner_code.h"
#include "gal_getlaunch.h"
#include "gal_objects.h"

void
gal_ldssr
(
  FILE         *fp,
  gal_objcat_t *objcat,
  gal_status_t *status
) 

{

  gal_status_t *stat ;
  
  char line1[1024], line2[1024], tag[1024], special[1024], intldesg[12], rcs[13], owner[8] ;
  
  int ly, lm, ld, dy, dm, dd, satnum, i, year, number ;
  
  gal_piece_t *piece ;
  
  gal_launch_t *launch ;

#define MAX_TAGS 14 

  char *tags[MAX_TAGS] = {
    "BARYCENTRIC ORBIT (EARTH-MOON)",       
    "CIRCUMLUNAR",                           
    "ESCAPED SOLAR SYSTEM",                  
    "HELIOCENTRIC ORBIT (SUN)",              
    "LUNAR IMPACT",                          
    "LUNAR LANDING",                         
    "MARS IMPACT",                           
    "MARS ORBIT",                            
    "NO ELEMENTS AVAILABLE",                 
    "NO INITIAL ELEMENTS",                   
    "SELENOCENTRIC ORBIT (MOON)",            
    "VENUS IMPACT",                          
    "VENUS LANDING",                         
    "VENUS ORBIT"
  } ;
               
  int status_code[MAX_TAGS+1] = {
    GAL_COS_UNKNOWN, 
    GAL_COS_BARYCENTRIC_ORBIT_EMB,       
    GAL_COS_CIRCUMLUNAR,                           
    GAL_COS_ESCAPED_SOLAR_SYSTEM,                  
    GAL_COS_HELIOCENTRIC_ORBIT,              
    GAL_COS_LUNAR_IMPACT,                          
    GAL_COS_LUNAR_LANDING,                         
    GAL_COS_MARS_IMPACT,                           
    GAL_COS_MARS_ORBIT,                            
    GAL_COS_NO_ELEMENTS_AVAILABLE,               
    GAL_COS_NO_INITIAL_ELEMENTS,                   
    GAL_COS_SELENOCENTRIC_ORBIT,            
    GAL_COS_VENUS_IMPACT,                          
    GAL_COS_VENUS_LANDING,                         
    GAL_COS_VENUS_ORBIT
  } ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return ;
  }

/*
 * Check for valid catalog object
 */
 
  if ( objcat == NULL || fp == NULL ) {
    gal_stsfree ( stat ) ;
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return ;
  }

/*
 * Initialize Object Catalog
 */
 
  gal_objcat_init ( objcat ) ;

/*
 * Find start position of data in report
 */
 
  gal_sseek ( fp, "Satellite Situation Report Objects in Orbit", 3, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  if ( gal_errc ( status ) ) {
    gal_stsfree ( stat ) ;
    return ;
  }

/*
 * Load data from report
 */

/*
 * -------------------------------------------------------------------------------
 * INT-ID/Name  CATALOG#  SOURCE   PERIOD    INCL   APOGEE    PERIGEE         RCS
 * -------------------------------------------------------------------------------
 * 2010-006C       36399   CIS       674.0    46.1    37661        510      3.2189
 * BREEZE-M DEB (TANK)                    Launched (02/12/2010)
 * 2009-038C       35691   US         87.7    51.6      165        159      0.2331
 * ANDE DEB (POLLUX CYLIN)                Launched (07/15/2009)  Decayed [01/10/2010]
 * 123456789012345678901234567890123456789123456789012112112341231234567121211211234
 * 
 * 2009-031B       35316   US     LUNAR IMPACT                          N/A
 * LCROSS                                 Launched (06/18/2009)
 * 2009-031A       35315   US     CIRCUMLUNAR                           N/A
 * LRO                                    Launched (06/18/2009)
 * "A39X10I2X1I2X1I4X3A7X2I2X1I2X1I4" <- Line 2
 * 1234567890112345123451231234567123456789012345678901234567890123456781231234567
 * "A11X5I5X3A7A38A3" <- Special case of line 1
 * 1234567890112345123451231234567123456781234567812345678912345678901123456789012
 * "A11X5I5X3A7D8.1D8.1D9.0D11.0D12.4" <- General case of line 1
 */
 
  while ( !feof ( fp ) ) {
  
    fgets ( line1, sizeof ( line1 ), fp ) ;
    
    gal_trim ( line2, line1 ) ;
    
    if ( strlen ( line2 ) == 0 ) {
       gal_stsfree ( stat ) ;
       return ;
    }
    
    gal_fscan ( "A11X5I5", line1, stat, intldesg, &satnum ) ;
    gal_stsadd ( stat, status ) ;

    piece = gal_piece_ins ( objcat, satnum, intldesg, &year, &number, stat ) ;
    gal_stsadd ( stat, status ) ;
    
    if ( piece == NULL ) {
       gal_stsfree ( stat ) ;
       return ;
    }

    gal_fscan ( "A11X5I5X3A7D8.1D8.1D9.0D11.0A12", line1, stat, 
            piece->intldesg,
            &piece->satnum,
            owner,
            &piece->period,
            &piece->inclo,
            &piece->apogee,
            &piece->perigee,
            rcs
          ) ;
    
/*
 * If the general case fails, try the special case
 */
           
    if ( gal_errc ( stat ) ) {
    
      gal_fscan ( "A11X5I5X3A7A38A3", line1, stat, piece->intldesg, &piece->satnum, owner, special, tag ) ;

      for ( i = 0; i < MAX_TAGS; i++ ) {
        if ( gal_instr ( special, tags[i] ) != -1 ) {
          piece->status = status_code[i+1] ;
          break ;
        }
      }
            
    } 
 
/*
 * Best guess of central body
 */
 
    if ( piece->status == GAL_COS_BARYCENTRIC_ORBIT_EMB ) {
      piece->central_body = GAL_OBJ_EARTH_MOON_BARYCENTER ;
    }
    else if ( piece->status == GAL_COS_CIRCUMLUNAR ) {
      piece->central_body = GAL_OBJ_MOON ;
    }
    else if ( piece->status == GAL_COS_ESCAPED_SOLAR_SYSTEM ) {
      piece->central_body = GAL_OBJ_SUN ;
    }
    else if ( piece->status == GAL_COS_HELIOCENTRIC_ORBIT ) {
      piece->central_body = GAL_OBJ_SUN ;
    }
    else if ( piece->status == GAL_COS_LUNAR_IMPACT ) {
      piece->central_body = GAL_OBJ_MOON ;
    }
    else if ( piece->status == GAL_COS_LUNAR_LANDING) {
      piece->central_body = GAL_OBJ_MOON ;
    }
    else if ( piece->status == GAL_COS_MARS_IMPACT ) {
      piece->central_body = GAL_OBJ_MARS ;
    }
    else if ( piece->status == GAL_COS_MARS_ORBIT ) {
      piece->central_body = GAL_OBJ_MARS ;
    }
    else if ( piece->status == GAL_COS_SELENOCENTRIC_ORBIT ) {
      piece->central_body = GAL_OBJ_MOON ;
    }
    else if ( piece->status == GAL_COS_VENUS_ORBIT ) {
      piece->central_body = GAL_OBJ_VENUS ;
    }
    else if ( piece->status == GAL_COS_VENUS_LANDING ) {
      piece->central_body = GAL_OBJ_VENUS ;
    }
    else if ( piece->status == GAL_COS_VENUS_IMPACT ) {
      piece->central_body = GAL_OBJ_VENUS ;
    }
    
    if ( piece->owner_code == GAL_COO_UNKNOWN ) {
      piece->owner_code = gal_objowner_code ( owner ) ;
    } ;
    
    if ( strcmp ( rcs, "         N/A" ) == 0 ) {
      piece->rcs = 0.0 ;
    }
    else {
      gal_fscan ( "D12.4", rcs, stat, &piece->rcs ) ;
    }
    
    fgets ( line2, sizeof ( line2 ), fp ) ;
        
    gal_fscan ( "A39X10I2X1I2X1I4X3A7X2I2X1I2X1I4", line2, stat, piece->name, &lm, &ld, &ly, tag, &dm, &dd, &dy ) ;
    
    if ( gal_instr ( piece->name, "PLAT" ) != -1 || 
         gal_instr ( piece->name, "DEB"  ) != -1 || 
         gal_instr ( piece->name, "R/B"  ) != -1 ) {
      piece->payload = 0 ;
    }

/*
 * Try and determine launcher rocket type
 */
     
    i = gal_instr ( piece->name, "R/B" ) ;
    
    if ( i != -1 ) {
      
      launch = gal_getlaunch ( objcat, piece->intldesg, stat ) ;
      gal_stsadd ( stat, status ) ;
      
      if ( launch != NULL && launch->lv_code == GAL_LV_UNKNOWN ) {
        launch->lv_code = gal_lvcode ( piece->name ) ;
      }
        
    }
    
    gal_cal2jd ( ly, lm, ld, &piece->launch_date1, &piece->launch_date2, stat ) ;
    gal_stsadd ( stat, status ) ;
    
    if ( strcmp ( tag, "Decayed" ) == 0 ) {
    
      gal_cal2jd ( dy, dm, dd, &piece->decay_date1, &piece->decay_date2, stat ) ;
      gal_stsadd ( stat, status ) ;
      piece->status = GAL_COS_DECAYED ;
    
    }
    
  }
  
  gal_stsfree ( stat ) ;
      
/*  
 * Finished.  
 */  
  
} 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
