/*  
 *  - - - - - - - - - -
 *   g a l _ l d t l e 
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine loads TLEs into an object catalog from a US Strategic
 *     Command Satellite Two line or Three Line TLE file.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file
 *     option             i           Load options (see Note 3)
 *
 *  Returned:  
 *  
 *     *objcat      gal_objcat_t      Pointer to object catalog
 *     *status      gal_status_t      Pointer to status structure
 * 
 *  Notes:
 *
 *  1) The latest TLEs can be downloaded from these sites:
 *
 *      http://www.space-track.org/perl/login.pl
 *
 *      http://celestrak.com/NORAD/elements/
 *
 *  2) The routine only understans files in US Strategic Command
 *     two line or three line format. If the file is in three
 *     line format then the names of the objects will be added
 *     to the catalog if they are not already set.
 *
 *  3) If option is set to GAL_LOADALL then all TLEs are loaded
 *     from the file. If option is set to GAL_LOADTAGGED then
 *     only TLEs for pieces of launch that have their TAG 
 *     value set as anything apart from 0 will be loaded.
 *
 *  4) Launches and pieces of launched are added to the contents
 *     of the object catalog, i.e. the catalog is not emptied
 *     before the load as it is for gal_ldssr.
 * 
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsfree           Free status structure
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_tlechksum         Calculate TLE checksum
 *     gal_getpiece          Get piece of launch from object catalog
 *     gal_instr             Search for substring in string
 *     gal_lvcode            Get launch vehicle code
 *     gal_tledec            Decode TLE
 *     gal_tleins            Insert TLE into object catalog
 *     gal_trimr             Trim whitespace from right of string
 *
 *  This revision:  
 * 
 *     2010 March 14 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 14 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>
#include <stdio.h>
#include "gal_ldtle.h"
#include "gal_status.h"
#include "gal_tlechksum.h"
#include "gal_lvcode.h"
#include "gal_pstrings.h"
#include "gal_tledec.h"
#include "gal_getpiece.h"

void
gal_ldtle
(
  FILE         *fp,
  int          option,
  gal_objcat_t *objcat,
  gal_status_t *status
) 

{

  int is3line, year, number, skip, i ;
  
  char card1[80], card2[80], name[80] ;
  
  gal_launch_t *launch ;
  
  gal_piece_t *piece ;
  
  gal_tle_t tle, *ptr ;
  
  gal_status_t *stat ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return ;
  }

/*
 * Check for valid catalog object
 */
 
  if ( objcat == NULL || fp == NULL ) {
    gal_stsfree ( stat ) ;
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return ;
  }

/*
 * Process the file
 */
 
  is3line = 0 ;
  
  while ( !feof ( fp ) ) {
  
    fgets ( card1, sizeof ( card1 ), fp ) ;
    
    gal_trimr ( card1, card1 ) ;
    if ( strlen ( card1 ) == 0 ) {
      break ;
    }

/*
 * Check to see if first line is a TLE card or a name
 */
     
    if ( card1[0] != '1' || gal_tlechksum ( card1 ) != card1[68] ) {
      is3line = 1 ;
    }
    
    if ( is3line ) {
    
      strcpy ( name, card1 ) ;
      
      fgets ( card1, sizeof ( card1 ), fp ) ;
      
    }
    
    fgets ( card2, sizeof ( card2 ), fp ) ;
    
/*
 * Only load when option is GAL_LOADALL or if the piece exists
 * in the object catalog and it is tagged.
 */
     
    skip = 0 ;
    
    if ( option == GAL_LOADTAGGED ) {
    
      gal_tledec ( card1, card2, &tle, stat ) ;
      gal_stsadd ( stat, status ) ;
      
      if ( gal_errc ( stat ) ) {
        skip = 1 ;
      }
      else {
    
        piece = gal_getpiece ( objcat, tle.intldesg, stat ) ;
      
        if ( gal_errc ( stat ) || piece->tag == 0 ) {
          skip = 1 ;
        }
        
      }
      
    }
    
/*
 * Load selected TLEs
 */

    if ( skip == 0 ) { 
    
      ptr = gal_tleins ( objcat, card1, card2, stat ) ;
      gal_stsadd ( stat, status ) ;
      
      if ( is3line ) {
      
        piece = gal_getpiece ( objcat, ptr->intldesg, stat ) ;
        gal_stsadd ( stat, status ) ;
        
        if ( gal_errc ( stat ) == 0 && strlen ( piece->name ) == 0 ) {
          strcpy ( piece->name, name ) ;
        }

        if ( gal_instr ( piece->name, "PLAT" ) != -1 || 
             gal_instr ( piece->name, "DEB"  ) != -1 || 
             gal_instr ( piece->name, "R/B"  ) != -1 ) {
          piece->payload = 0 ;
        }

/*
 * Try and determine launcher rocket type
 */
     
        i = gal_instr ( piece->name, "R/B" ) ;
    
        if ( i != -1 ) {
            
          launch = objcat->launch ;

          while ( launch != NULL ) {
/* THIS NEEDS FIXING - YEAR AND NUMBER UNASSIGNED */
            if ( launch->year == year && launch->number == number ) {
              break ;
            }
            launch = launch->next ;
          }
      
          if ( launch != NULL && launch->lv_code == GAL_LV_UNKNOWN ) {
            launch->lv_code = gal_lvcode ( piece->name ) ;
          }
        
        }
        
      }
      
    }
    
  }
     
  gal_stsfree ( stat ) ;
      
/*  
 * Finished.  
 */  
  
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
