/*  
 *  - - - - - - - - - -
 *   g a l _ l d t l e 
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine loads TLEs into an object catalog from a US Strategic
 *     Command Satellite Two line or Three Line TLE file.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *fp              FILE          Pointer to open file
 *     option             i           Load options (see Note 3)
 *
 *  Returned:  
 *  
 *     *objcat      gal_objcat_t      Pointer to object catalog
 *     *status      gal_status_t      Pointer to status structure
 * 
 *  Notes:
 *
 *  1) The latest TLEs can be downloaded from these sites:
 *
 *      http://www.space-track.org/perl/login.pl
 *
 *      http://celestrak.com/NORAD/elements/
 *
 *  2) The routine only understans files in US Strategic Command
 *     two line or three line format. If the file is in three
 *     line format then the names of the objects will be added
 *     to the catalog if they are not already set.
 *
 *  3) If option is set to GAL_LOADALL then all TLEs are loaded
 *     from the file. If option is set to GAL_LOADTAGGED then
 *     only TLEs for pieces of launch that have their TAG 
 *     value set as anything apart from 0 will be loaded.
 *
 *  4) Launches and pieces of launched are added to the contents
 *     of the object catalog, i.e. the catalog is not emptied
 *     before the load as it is for gal_ldssr.
 * 
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsfree           Free status structure
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_tlechksum         Calculate TLE checksum
 *     gal_getpiece          Get piece of launch from object catalog
 *     gal_instr             Search for substring in string
 *     gal_lvcode            Get launch vehicle code
 *     gal_tledec            Decode TLE
 *     gal_tleins            Insert TLE into object catalog
 *     gal_trimr             Trim whitespace from right of string
 *
 *  This revision:  
 * 
 *     2010 March 14 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 14 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_LDTLE_H_  
#define _GAL_LDTLE_H_ 1  

#include <stdio.h>
#include "gal_usstratcom.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

void
gal_ldtle
(
  FILE         *fp,
  int          option,
  gal_objcat_t *objcat,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_LDTLE_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
