/*  
 *  - - - - - - - - - - - 
 *   g a l _ l v n a m e
 *  - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the name of a launch vehicle.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     launcher            i          Launcher identifier code
 *  
 *  Returned:  
 *  
 *     *name              c[]         Pointer to name string
 *     *status       gal_status_t     Pointer to status structure
 *     *gal_lvname        c[]         Pointer to name string, NULL if failure
 * 
 *  Notes:
 *
 *  1) The header file "gal_tle.h" defines the applicable GAL_LV_* constants.
 *
 *  2) If the specified identifier code is not known to the routine then
 *     the error code GAL_INVALID_ID is set, and the routine returns NULL.
 * 
 *  Called:
 *
 *     gal_stsinit                    Initialize status structure
 *     gal_errset                     Set error code
 *
 *  This revision:  
 * 
 *     2010 March 7 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>
#include "gal_lvname.h"
#include "gal_status.h"
#include "gal_usstratcom.h"

char *
gal_lvname
(
  int launcher,
  char *name,
  gal_status_t *status
)

{


  char *launcher_names[GAL_MAX_LAUNCHERS] = {
    "UNKNOWN                                ",
    "APEX                                   ", 
    "ARIANE 1                               ", 
    "ARIANE 2                               ", 
    "ARIANE 3                               ", 
    "ARIANE 40                              ", 
    "ARIANE 40+                             ", 
    "ARIANE 40+3                            ", 
    "ARIANE 42L                             ", 
    "ARIANE 42L+3                           ", 
    "ARIANE 42P                             ", 
    "ARIANE 42P+                            ", 
    "ARIANE 42P+3                           ", 
    "ARIANE 44L                             ", 
    "ARIANE 44L+                            ", 
    "ARIANE 44L+3                           ", 
    "ARIANE 44LP                            ", 
    "ARIANE 44LP+                           ", 
    "ARIANE 44LP+3                          ", 
    "ARIANE 44P                             ", 
    "ARIANE 44P+3                           ", 
    "ARIANE 5                               ", 
    "ASLV-D3                                ", 
    "ASLV-D4                                ", 
    "ATHENA 1 (OAM)                         ", 
    "ATHENA 2                               ", 
    "ATLAS                                  ", 
    "ATLAS 1 CENTAUR                        ", 
    "ATLAS 14E                              ", 
    "ATLAS 2 CENTAUR                        ", 
    "ATLAS 28E                              ", 
    "ATLAS 2A                               ", 
    "ATLAS 2A CENTAUR                       ", 
    "ATLAS 2AS CENTAUR                      ", 
    "ATLAS 34F                              ", 
    "ATLAS 35F                              ", 
    "ATLAS 3A CENTAUR                       ", 
    "ATLAS 3B CENTAUR                       ", 
    "ATLAS 41E                              ", 
    "ATLAS 42E                              ", 
    "ATLAS 5 CENTAUR                        ", 
    "ATLAS 5 STAR 48-B                      ", 
    "ATLAS 55E                              ", 
    "ATLAS 67F                              ", 
    "ATLAS 75E                              ", 
    "ATLAS AGENA                            ", 
    "ATLAS AGENA A                          ", 
    "ATLAS AGENA B                          ", 
    "ATLAS AGENA D                          ", 
    "ATLAS CENTAUR                          ", 
    "ATLAS CENTAUR 2                        ", 
    "ATLAS D                                ", 
    "ATLAS D 5                              ", 
    "ATLAS D 7                              ", 
    "ATLAS F                                ", 
    "ATLAS F BURNER 2                       ", 
    "ATLAS H                                ", 
    "BLACK ARROW                            ", 
    "BLOCK DM                               ", 
    "BLOCK DM-SL                            ", 
    "BREEZE-KM                              ", 
    "BREEZE-M                               ", 
    "CELESTIS 01/PEGASUS                    ", 
    "CELESTIS 02/TAURUS                     ", 
    "CELESTIS 03/TAURUS                     ", 
    "CZ-1                                   ", 
    "CZ-2                                   ", 
    "CZ-2B                                  ", 
    "CZ-2C                                  ", 
    "CZ-2D                                  ", 
    "CZ-2E                                  ", 
    "CZ-2F                                  ", 
    "CZ-3                                   ", 
    "CZ-3A                                  ", 
    "CZ-3B                                  ", 
    "CZ-3C                                  ", 
    "CZ-4                                   ", 
    "CZ-4B                                  ", 
    "CZ-4C                                  ", 
    "CZ-5                                   ", 
    "DELTA                                  ", 
    "DELTA 1                                ", 
    "DELTA 1 (+CAMEO)                       ", 
    "DELTA 1 (CEP 1)                        ", 
    "DELTA 1 (ITOS-B)                       ", 
    "DELTA 2                                ", 
    "DELTA 2  (DUVE)                        ", 
    "DELTA 3                                ", 
    "DELTA 4                                ", 
    "DELTA 4H                               ", 
    "DIAMANT                                ", 
    "DIAMANT (MIKA)                         ", 
    "DIAMANT B                              ", 
    "DIAMANT B-P4                           ", 
    "DNEPR 1                                ", 
    "FALCON 1                               ", 
    "FREGAT                                 ", 
    "GSLV                                   ", 
    "H-1                                    ", 
    "H-1 (MABES)                            ", 
    "H-2                                    ", 
    "H-2A                                   ", 
    "H-2B                                   ", 
    "IABS                                   ", 
    "IRIS                                   ", 
    "IRS P2                                 ", 
    "IUS                                    ", 
    "JUNO II                                ", 
    "M-3C                                   ", 
    "M-3H                                   ", 
    "M-3S                                   ", 
    "M-3S2                                  ", 
    "M-4S                                   ", 
    "M-5                                    ", 
    "MARS 96                                ", 
    "MINOTAUR                               ", 
    "N-1                                    ", 
    "N-2                                    ", 
    "OPTUS B1 (STAR 63F)                    ", 
    "PAM-S                                  ", 
    "PEGASUS                                ", 
    "PSLV                                   ", 
    "PSLV 1C                                ", 
    "SAFIR 2                                ", 
    "SATURN 1                               ", 
    "SATURN 1B                              ", 
    "SATURN 5                               ", 
    "SCOUT A                                ", 
    "SCOUT A-1                              ", 
    "SCOUT B                                ", 
    "SCOUT B-1                              ", 
    "SCOUT D-1                              ", 
    "SCOUT D-1 D                            ", 
    "SCOUT E-1                              ", 
    "SCOUT F-1                              ", 
    "SCOUT G-1                              ", 
    "SCOUT X-1                              ", 
    "SCOUT X-2M                             ", 
    "SCOUT X-3                              ", 
    "SCOUT X-3M                             ", 
    "SCOUT X-4                              ", 
    "SHAVIT                                 ", 
    "SL-04                                  ", 
    "SL-1                                   ", 
    "SL-11                                  ", 
    "SL-12                                  ", 
    "SL-13                                  ", 
    "SL-14                                  ", 
    "SL-16                                  ", 
    "SL-18                                  ", 
    "SL-19                                  ", 
    "SL-21                                  ", 
    "SL-23                                  ", 
    "SL-24                                  ", 
    "SL-26                                  ", 
    "SL-3                                   ", 
    "SL-4                                   ", 
    "SL-5                                   ", 
    "SL-6                                   ", 
    "SL-7                                   ", 
    "SL-8                                   ", 
    "SL-9                                   ", 
    "SLV-3                                  ", 
    "SS-18                                  ", 
    "SSN-23                                 ", 
    "STRELA                                 ", 
    "TAURUS                                 ", 
    "THOR ABLE                              ", 
    "THOR ABLESTAR                          ", 
    "THOR AGENA B                           ", 
    "THOR AGENA D                           ", 
    "THOR ALTAIR                            ", 
    "THOR BURNER 2                          ", 
    "THOR BURNER 2A                         ", 
    "THOR DELTA 1                           ", 
    "THORAD AGENA D                         ", 
    "THORAD DELTA 1                         ", 
    "TITAN 2                                ", 
    "TITAN 2G                               ", 
    "TITAN 3                                ", 
    "TITAN 34B                              ", 
    "TITAN 34B AGENA                        ", 
    "TITAN 34B AGENA D                      ", 
    "TITAN 34D                              ", 
    "TITAN 34D AGENA D                      ", 
    "TITAN 34D IUS                          ", 
    "TITAN 3A TRANSTAGE                     ", 
    "TITAN 3B AGENA                         ", 
    "TITAN 3C                               ", 
    "TITAN 3C TRANSTAGE                     ", 
    "TITAN 3D                               ", 
    "TITAN 3E                               ", 
    "TITAN 3E CENTAUR                       ", 
    "TITAN 4                                ", 
    "TITAN 4 CENTAUR                        ", 
    "TITAN 401 CENTAUR                      ", 
    "TITAN 4A                               ", 
    "TITAN 4A CENTAUR                       ", 
    "TITAN 4B                               ", 
    "TITAN 4B CENTAUR                       ", 
    "TOS                                    ", 
    "VANGUARD                               "
  } ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  if ( launcher < 0 || launcher > GAL_MAX_LAUNCHERS ) {
    gal_errset ( __FILE__, __LINE__, GAL_INVALID_ID, status ) ;
    return NULL ;
  }
  
  strcpy ( name, launcher_names[launcher] ) ;
  
  return name ;
  
/*  
 * Finished.  
 */ 
  
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
