/*  
 *  - - - - - - - - - - - - - - - - - -
 *   g a l _ o b j o w n e r _ c o d e 
 *  - - - - - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the code of a catalog object's owner
 *     organization or country for the specified US Space Command
 *     abbreviation code.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *owner                  c[]        US Space Command Owner identifier code
 *  
 *  Returned:  
 *  
 *     gal_objowner_code        i         GAL Catalog Object Owner Code
 * 
 *  Notes:
 *
 *  1) The header file "gal_tle.h" defines the applicable GAL_COO_* constants.
 *
 *  2) If the specified identifier code is not known to the routine then
 *     the error code then the routine returns GAL_COO_UNKNOWN.
 * 
 *  Called:
 *
 *     gal_stsinit                    Initialize status structure
 *     gal_errset                     Set error code
 *
 *  This revision:  
 * 
 *     2010 March 7 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <string.h>
#include "gal_status.h"
#include "gal_objowner_code.h"
#include "gal_usstratcom.h"

int
gal_objowner_code
(
  char *owner
) 

{

#define MAX_OWNERS 77

  char *owner_names[MAX_OWNERS] = {
    "AB     ",
    "AC     ",
    "ALG    ",
    "ARG    ",
    "ARGN   ",
    "AUS    ",
    "BER    ",
    "BERM   ",
    "BRAZ   ",
    "CA     ",
    "CHBZ   ",
    "CHLE   ",
    "CIS    ",
    "COL    ",
    "CZCH   ",
    "DEN    ",
    "EGYP   ",
    "ESA    ",
    "ESRO   ",
    "EUME   ",
    "EUTE   ",
    "FGER   ",
    "FR     ",
    "FRG    ",
    "FRRG   ",
    "GER    ",
    "GLOB   ",
    "GREC   ",
    "IM     ",
    "IND    ",
    "INDO   ",
    "INMA   ",
    "IRAN   ",
    "IRID   ",
    "ISRA   ",
    "ISRO   ",
    "ISS    ",
    "IT     ",
    "ITSO   ",
    "JPN    ",
    "KOR    ",
    "LUXE   ",
    "MALA   ",
    "MEX    ",
    "NATO   ",
    "NETH   ",
    "NICO   ",
    "NIG    ",
    "NKOR   ",
    "NOR    ",
    "ORB    ",
    "PAKI   ",
    "POR    ",
    "PRC    ",
    "PRES   ",
    "RASC   ",
    "ROC    ",
    "RP     ",
    "SAFR   ",
    "SAUD   ",
    "SEAL   ",
    "SKOR   ",
    "SPN    ",
    "STCT   ",
    "SWED   ",
    "SWTZ   ",
    "THAI   ",
    "TURK   ",
    "UAE    ",
    "UK     ",
    "UNKN   ",
    "US     ",
    "USA    ",
    "USBZ   ",
    "USSR   ",
    "VENZ   ",
    "VTNM   "
  } ;

  int owner_code[MAX_OWNERS] = {
    GAL_COO_ARABSAT,
    GAL_COO_ASIASAT_CORP,
    GAL_COO_ALGERIA,
    GAL_COO_ARGENTINA,
    GAL_COO_ARGENTINA,
    GAL_COO_AUSTRALIA,
    GAL_COO_BERMUDA,
    GAL_COO_BERMUDA,
    GAL_COO_BRAZIL,
    GAL_COO_CANADA,
    GAL_COO_PRC_BRAZIL,
    GAL_COO_CHILE,
    GAL_COO_CIS,
    GAL_COO_COLUMBIA,
    GAL_COO_CZECHOSLOVAKIA,
    GAL_COO_DENMARK,
    GAL_COO_EGYPT,
    GAL_COO_ESA,
    GAL_COO_ESRO,
    GAL_COO_EUMETSAT,
    GAL_COO_EUTELSAT,
    GAL_COO_FRANCE_GERMANY,
    GAL_COO_FRANCE,
    GAL_COO_GERMANY,
    GAL_COO_FRANCE_GERMANY,
    GAL_COO_GERMANY,
    GAL_COO_GLOBALSTAR,
    GAL_COO_GREECE,
    GAL_COO_INMARSAT,
    GAL_COO_INDIA,
    GAL_COO_INDONESIA,
    GAL_COO_INMARSAT,
    GAL_COO_IRAN,
    GAL_COO_IRIDIUM,
    GAL_COO_ISRAEL,
    GAL_COO_ISRO,
    GAL_COO_ISS,
    GAL_COO_ITALY,
    GAL_COO_INTELSAT,
    GAL_COO_JAPAN,
    GAL_COO_KOREA,
    GAL_COO_LUXEMBOURG,
    GAL_COO_MALAYSIA,
    GAL_COO_MEXICO,
    GAL_COO_NATO,
    GAL_COO_NETHERLANDS,
    GAL_COO_NEW_ICO,
    GAL_COO_NIGERIA,
    GAL_COO_NORTH_KOREA,
    GAL_COO_NORWAY,
    GAL_COO_GLOBALSTAR,
    GAL_COO_PAKISTAN,
    GAL_COO_PORTUGAL,
    GAL_COO_PRC,
    GAL_COO_PRC_ESA,
    GAL_COO_TAIWAN,
    GAL_COO_PHILIPPINES,
    GAL_COO_RASC,
    GAL_COO_SOUTH_AFRICA,
    GAL_COO_SAUDI_ARABIA,
    GAL_COO_SEA_LAUNCH,
    GAL_COO_SOUTH_KOREA,
    GAL_COO_SPAIN,
    GAL_COO_SINGPORE_TAIWAN,
    GAL_COO_SWEDEN,
    GAL_COO_SWITZERLAND,
    GAL_COO_THAILAND,
    GAL_COO_TURKEY,
    GAL_COO_UNITED_ARAB_EMIRATES,
    GAL_COO_UNITED_KINGDOM,
    GAL_COO_UNKNOWN,
    GAL_COO_USA,
    GAL_COO_USA,
    GAL_COO_USA_BRAZIL,
    GAL_COO_CIS,
    GAL_COO_VENEZUELA,
    GAL_COO_VIETNAM
  } ;

  int i ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  for ( i = 0; i < MAX_OWNERS; i++ ) {
    if ( strcmp ( owner, owner_names[i] ) == 0 ) {
      return owner_code[i] ;
    }
  }
  
  return GAL_COO_UNKNOWN ;
  
/*  
 * Finished.  
 */ 

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
