/*  
 *  - - - - - - - - - - - - -
 *   g a l _ o s c 2 m e a n   
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine converts osculating Keplerian elements
 *     to mean elements suitable for use with the SGP4
 *     orbit propagator.
 *  
 *  Status: 
 *  
 *     Support routine  
 *  
 *  Given:  
 *
 *     osc              d[6]        Osculating elements ( see Note 1 )
 *  
 *  Returned:  
 *  
 *     mean             d[6]        Mean elements ( see Note 1 ) 
 *     *status       gal_status_t   Pointer to status structure 
 *
 *  Notes:
 *
 *  1) The elements are stored as follows:
 *
 *     [0] - Argument of perigee ( degrees )
 *     [1] - Right ascension of ascending node ( degrees )
 *     [2] - Inclination ( degrees )
 *     [3] - Mean motion ( rev / day )
 *     [4] - Eccentricity
 *     [5] - Mean anomaly ( degrees ) 
 *
 *  2) The conversion process will not always converge to a solution, so
 *     it is important that the user checks the routine return status. Testing
 *     against the complete unclassified catalog (as of January 2009) it 
 *     was found that out of 11766 objects, 11103 (~94%) converged and matched 
 *     the NORAD values exactly, 9 (~0.07%) objects converged but did not exactly 
 *     match the NORAD values, and 654 (~5%) objects failed to converge.
 *
 *     Propagating the 9 objects that converged but do not match NORAD over
 *     a 10 day period, shows that the velocities match within 1 m/s to those 
 *     NORAD keps. x and y positions match within 1 km, and the worst difference 
 *     value for z position is 11km after 10 days.
 *
 *  3) If the solution does not converge then the error status GAL_NO_CONVERGENCE
 *     is set.
 *
 *  References:
 *
 *  Conversion of Osculating Orbital Elements into Mean Elements,
 *  H. G. Walter, Astronomical Journal, 72(4), 994-997 (1967)
 *  This revision:  
 * 
 *  NORAD TLE Conversion from Osculating Element, Byoung-Sun Lee, 
 *  Journal Astronomy Space Science 19(4), 395-402 (2002)
 *
 *  Called:
 *
 *     gal_sgp4           NORAD SGP4 Propagator
 *     gal_pv2kep         pv-vector to Keplerian elements
 *     gal_minv6          Maxtrix inverse (6x6)
 *     gal_sma2mm         Semi-major axis to mean motion
 *     gal_anp            Normalise angle to 0 to 2pi
 *     gal_anpm           Normalise and to +/- pi
 *     gal_settle         Setup tle structure
 *     gal_stsinit        Initialize status structure
 *     gal_stsalloc       Create status structure
 *     gal_stsfree        Free status structure
 *     gal_stsadd         Merge status structure
 *     gal_errset         Set error code
 *     gal_errc           Get error count
 *
 *  This revision:  
 * 
 *     2010 May 1 Paul Willmott General tidy-up and improved error handling. 
 *
 *  Revision History:
 *
 *     2010 February 8 Paul Willmott Changed to use GAL status recording
 *                                   mechanism. 
 *
 *     2010 January 30 Paul Willmott Updated for change in gal_settle parameters. 
 *
 *     2009 January 31 Paul Willmott Baseline
 *
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <math.h>
#include <float.h>
#include "gal_osc2mean.h"
#include "gal_math_macros.h"
#include "gal_date_macros.h"
#include "gal_sgp4.h"
#include "gal_pv2kep.h"
#include "gal_settle.h"
#include "gal_sgp4init.h"
#include "gal_minv6.h"
#include "gal_usstratcom.h"
#include "gal_sgp4t.h"
#include "gal_sma2mm.h"
#include "gal_anp.h"
#include "gal_anpm.h"
#include "gal_gm.h"
#include "gal_status.h"

void f
(
  double epoch1,
  double epoch2,
  gal_gm_t *gm,
  double mean[6],
  double osc[6],
  gal_status_t *status
)
  
{

/*
 * Macro for error handler
 */
 
#define ERROR( errno ) \
if ( stat != NULL ) { \
  gal_stsfree ( stat ) ; \
} \
gal_errset ( __FILE__, __LINE__, ( errno ), status ) ; \
return

  gal_tle_t tle ;
  
  gal_sgp4_t sgp4 ;
  
  double pv[2][3], sma, ecc, raan, argp, ma, inc, p, v, truelon, u, lonper ;

  gal_status_t *stat = NULL ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Clear return status 
 */
 
  gal_stsinit ( status ) ;
  
/*
 * Create status structure for calls
 */
 
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    ERROR ( GAL_ALLOC_FAILED ) ;
  }

/*
 * Form TLE structure
 */
 
  gal_settle ( epoch1, epoch2, mean, &tle, stat ) ;
  if ( gal_errc ( stat ) ) {  
    gal_stsadd ( stat, status ) ;
    ERROR ( GAL_STSADD_BREAKPOINT ) ;
  }
   
/*
 * Initialize SGP4 structure
 */

  gal_sgp4init ( gm, &tle, &sgp4, stat ) ;
  if ( gal_errc ( stat ) ) {  
    gal_stsadd ( stat, status ) ;
    ERROR ( GAL_STSADD_BREAKPOINT ) ;
  }
  
/*
 * Propagate orbit
 */
 
  gal_sgp4 ( &sgp4, epoch1, epoch2, pv, stat ) ;
  if ( gal_errc ( stat ) ) {  
    gal_stsadd ( stat, status ) ;
    ERROR ( GAL_STSADD_BREAKPOINT ) ;
  }

/*
 * Derive Keplerian elements from position & velocity
 */
 
  gal_pv2kep ( gm->gm, pv, &sma, &ecc, &raan, &argp, &ma, &inc, &p, &v, &truelon, &u, &lonper ) ;

/*
 * Convert to degrees, and populate return results array
 */

  osc[0] = GAL_R2D * argp ;
  osc[1] = GAL_R2D * raan ;
  osc[2] = GAL_R2D * inc ;
  osc[3] = gal_sma2mm ( sma, gm->gm ) * GAL_D2S / GAL_2PI ; /* convert to revs per day */
  osc[4] = ecc ;
  osc[5] = GAL_R2D * ma ;

  gal_stsfree ( stat ) ;
  
/*  
 * Finished.  
 */  

}

void
gal_osc2mean
(
  double epoch1,
  double epoch2,
  double osc[6],
  gal_gm_t *gm,
  double mean[6],
  gal_status_t *status
) 
  
{

/*
 * Macro for error handler
 */

#undef ERROR 
#define ERROR( errno ) \
if ( stat != NULL ) { \
  gal_stsfree ( stat ) ; \
} \
gal_errset ( __FILE__, __LINE__, ( errno ), status ) ; \
return 

  int i, j, converged, iter ;

  double c[6][6], newosc[6], dx[6], delmean[6],  delosc[6], delta[6], diff,  dfdx[6][6] ;

  double tol  = 1e-15 ;
  double step = 1e-9 ;
  int maxiter = 80 ;

  gal_status_t *stat = NULL ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Clear return status
 */
 
  gal_stsinit ( status ) ;
  
/*
 * Create status structure fir calls
 */
 
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    ERROR ( GAL_ALLOC_FAILED ) ;
  }
  
  for ( i = 0; i < 6; i++ ) {
    mean[i] = osc[i] ;
  }

/*
 * Iterate until convergence or time-out
 */
 
  iter = 0 ;  
  do {

/*
 * Propagate orbit and find new guess set of elements
 */
   
    f ( epoch1, epoch2, gm, mean, newosc, stat ) ;
    if ( gal_errc ( stat ) ) {
      gal_stsadd ( stat, status ) ;
      ERROR ( GAL_STSADD_BREAKPOINT ) ;
    }

/*
 * Find differences to known osculating elements
 */
 
    diff = 0.0 ;
    for ( i = 0; i < 6; i++ ) {
      delta[i] = osc[i] - newosc[i] ;
      diff += delta[i] * delta[i] ;
    }

    converged =  diff < tol || iter > maxiter ; 
    iter++ ;
    
/*
 * Calculate new guess if it hasn't converged yet
 */
 
    if ( !converged ) {

/*
 * Calculate partial derivatives
 */
     
      for ( i = 0; i < 6; i++ ) {
        dx[i] = step * mean[i] ;
        for ( j = 0; j < 6; j ++ ) {
          delmean[j] = mean[j] ;
        }
        delmean[i] += dx[i] ;
        f ( epoch1, epoch2, gm, delmean, delosc, stat ) ;
        gal_stsadd ( stat, status ) ;
        for ( j = 0; j < 6; j ++ ) {
          dfdx[i][j] = ( delosc[j] - newosc[j] ) / dx[i] ;
        } 
        
      }    

/*
 * Next guess
 */
 
      gal_minv6 ( dfdx, c, stat ) ; 
      if ( gal_errc ( stat ) ) {
        gal_stsadd ( stat, status ) ;
        ERROR ( GAL_STSADD_BREAKPOINT ) ;
      }
      
      for ( i = 0 ; i < 6; i++ ) {
        for ( j = 0; j < 6; j++ ) {
          mean[i] += c[j][i] * delta[j] ; 
        }
        
      }
      
    }
       
  } while ( !converged ) ;

/*
 *     [0] - Argument of perigee ( degrees )
 *     [1] - Right ascension of ascending node ( degrees )
 *     [2] - Inclination ( degrees )
 *     [3] - Mean motion ( rev / day )
 *     [4] - Eccentricity
 *     [5] - Mean anomaly ( degrees )  
 */

/*
 * Quality Control & Unit Conversion
 */
 
  f ( epoch1, epoch2, gm, mean, newosc, stat ) ;
  if ( gal_errc ( stat ) ) {
    gal_stsadd ( stat, status ) ;
    ERROR ( GAL_STSADD_BREAKPOINT ) ;
  }
  
  for ( i = 0; i < 6; i++ ) {
    if ( fabs ( newosc[i] - osc[i] ) > 1e-5 ) {
      ERROR ( GAL_NO_CONVERGENCE ) ;
    }
  }
  
  mean[5] = GAL_R2D * gal_anp  ( GAL_D2R * mean[5] ) ;
  mean[0] = GAL_R2D * gal_anp  ( GAL_D2R * mean[0] ) ;
  mean[1] = GAL_R2D * gal_anp  ( GAL_D2R * mean[1] ) ;
  mean[2] = GAL_R2D * gal_anpm ( GAL_D2R * mean[2] ) ;

  for ( i = 0; i < 6; i++ ) {
    if ( isnan ( mean[i] ) ) {
      ERROR ( GAL_NO_CONVERGENCE ) ;
    }
  }
  if ( mean[4] < 0.0 || mean[2] < 0.0 ) {
      ERROR ( GAL_NO_CONVERGENCE ) ;
  } 

  gal_stsfree ( stat ) ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
