/*  
 *  - - - - - - - - - - - - -
 *   g a l _ o s c 2 m e a n   
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine converts osculating Keplerian elements
 *     to mean elements suitable for use with the SGP4
 *     orbit propagator.
 *  
 *  Status: 
 *  
 *     Support routine  
 *  
 *  Given:  
 *
 *     osc              d[6]        Osculating elements ( see Note 1 )
 *  
 *  Returned:  
 *  
 *     mean             d[6]        Mean elements ( see Note 1 ) 
 *     *status       gal_status_t   Pointer to status structure 
 *
 *  Notes:
 *
 *  1) The elements are stored as follows:
 *
 *     [0] - Argument of perigee ( degrees )
 *     [1] - Right ascension of ascending node ( degrees )
 *     [2] - Inclination ( degrees )
 *     [3] - Mean motion ( rev / day )
 *     [4] - Eccentricity
 *     [5] - Mean anomaly ( degrees ) 
 *
 *  2) The conversion process will not always converge to a solution, so
 *     it is important that the user checks the routine return status. Testing
 *     against the complete unclassified catalog (as of January 2009) it 
 *     was found that out of 11766 objects, 11103 (~94%) converged and matched 
 *     the NORAD values exactly, 9 (~0.07%) objects converged but did not exactly 
 *     match the NORAD values, and 654 (~5%) objects failed to converge.
 *
 *     Propagating the 9 objects that converged but do not match NORAD over
 *     a 10 day period, shows that the velocities match within 1 m/s to those 
 *     NORAD keps. x and y positions match within 1 km, and the worst difference 
 *     value for z position is 11km after 10 days.
 *
 *  3) If the solution does not converge then the error status GAL_NO_CONVERGENCE
 *     is set.
 *
 *  References:
 *
 *  Conversion of Osculating Orbital Elements into Mean Elements,
 *  H. G. Walter, Astronomical Journal, 72(4), 994-997 (1967)
 *  This revision:  
 * 
 *  NORAD TLE Conversion from Osculating Element, Byoung-Sun Lee, 
 *  Journal Astronomy Space Science 19(4), 395-402 (2002)
 *
 *  Called:
 *
 *     gal_sgp4           NORAD SGP4 Propagator
 *     gal_pv2kep         pv-vector to Keplerian elements
 *     gal_minv6          Maxtrix inverse (6x6)
 *     gal_sma2mm         Semi-major axis to mean motion
 *     gal_anp            Normalise angle to 0 to 2pi
 *     gal_anpm           Normalise and to +/- pi
 *     gal_settle         Setup tle structure
 *     gal_stsinit        Initialize status structure
 *     gal_stsalloc       Create status structure
 *     gal_stsfree        Free status structure
 *     gal_stsadd         Merge status structure
 *     gal_errset         Set error code
 *     gal_errc           Get error count
 *
 *  This revision:  
 * 
 *     2010 May 1 Paul Willmott General tidy-up and improved error handling. 
 *
 *  Revision History:
 *
 *     2010 February 8 Paul Willmott Changed to use GAL status recording
 *                                   mechanism. 
 *
 *     2010 January 30 Paul Willmott Updated for change in gal_settle parameters. 
 *
 *     2009 January 31 Paul Willmott Baseline
 *
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_OSC2MEAN_H_  
#define _GAL_OSC2MEAN_H_ 1  

#include "gal_gm.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void
gal_osc2mean
(
  double epoch1,
  double epoch2,
  double osc[6],
  gal_gm_t *gm,
  double mean[6],
 gal_status_t *status
) ;
 
__END_DECLS  
  
#endif /* !_GAL_OSC2MEAN_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
