/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ p i e c e _ i n s
 *  - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine inserts a piece of launch into an object catalog.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *objcat           gal_objcat_t    Pointer to object catalog
 *     satnum                 i          US Strategic Command Object number
 *     *intldesg             c[]         International Designator (COSPAR/WDC-A-R&S)
 *
 *  Returned:  
 * 
 *     *year                  i          Year of launch
 *     *number                i          Number of launch within year 
 *     *status           gal_status_t    Pointer to status structure
 *     *gal_piece_ins    gal_piece_t     Pointer to piece of launch 
 *                                       structure, NULL if failure
 * 
 *  Notes:
 *
 *  1) If the piece of launch is already in the catalog then a pointer
 *     is returned to the existing structure. i.e. no duplicates
 *     are created.
 *
 *  2) If an internal error occurs then the error code
 *     GAL_ALLOC_FAILED is set and the routine returns NULL.
 *
 *  3) The piece launches are stored in a linked list within the
 *     catalog, the order is A, B, ... AA, BB, ... AAA, AAB, ...
 *
 *  4) The international Designator must be in the format:
 *
 *          "YYYY-NNNPPP" e.g. "1997-051VX "
 * 
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsalloc          Create status structure
 *     gal_stsfree           Free status structure
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_fscan             Decode FORTRAN string
 *     gal_launch_ins        Insert launch into catalog
 *     gal_trimr             Trim whitespace from right of string
 *     gal_justl             Justify string in field to left
 *
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include <string.h>
#include "gal_piece_ins.h"
#include "gal_status.h"
#include "gal_objects.h"
#include "gal_fscan.h"
#include "gal_launch_ins.h"
#include "gal_trimr.h"
#include "gal_justl.h"

int 
comp
(
  char *s1,
  char *s2
)

{

  int l1, l2 ;
  
  char s[4], t[4] ;
  
  gal_trimr ( s, s1 ) ;
  gal_trimr ( t, s2 ) ;
  
  l1 = strlen ( s ) ;
  l2 = strlen ( t ) ;
  
  if ( l1 < l2 ) {
    return 1 ;
  }
  else if ( l1 > l2 ) {
    return -1 ;
  }
  else {
    return strcmp ( s, t ) ;
  }
  
}

gal_piece_t *
gal_piece_ins
(
  gal_objcat_t *objcat,
  int          satnum,
  char         *intldesg,
  int          *year,
  int          *number,
  gal_status_t *status
) 

{

  gal_piece_t *ptr, *lptr ;
  
  gal_status_t *stat ;
  
  char piece[4] ;

  gal_launch_t *launch ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }

/*
 * Decompose international designator
 */
 
  gal_fscan ( "I4X1I3A3", intldesg, stat, year, number, piece ) ;
  gal_stsadd ( stat, status ) ;

  if ( gal_errc ( status ) ) {
    gal_stsfree ( stat ) ;
    return NULL ;
  }
  
  gal_justl ( piece, piece, 3 ) ;
  
/*
 * Check for valid object catalog
 */
 
  if ( objcat == NULL ) {
    gal_stsfree ( stat ) ;
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return NULL ;
  }

/*
 * Find or insert launch
 */
 
  launch = gal_launch_ins ( objcat, *year, *number, stat ) ;
  gal_stsadd ( stat, status ) ;

  if ( gal_errc ( status ) ) {
    gal_stsfree ( stat ) ;
    return NULL ;
  }
     
/*
 * --------------------
 * Find insertion point
 * --------------------
 */

/*
 * Handle empty list case
 */
 
  if ( launch->piece == NULL ) {
  
    if ( ( ptr = ( gal_piece_t * ) malloc ( sizeof ( gal_piece_t ) ) ) == NULL ) {
      gal_stsfree ( stat ) ;
      gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
      return NULL ;
    }
    
    launch->piece = ptr ;
    ptr->next = NULL ;
    
  }
  else {
  
/*
 * Handle First case equal
 */
   
    ptr = launch->piece ;
    
    if ( comp ( ptr->piece, piece ) == 0 ) {
      gal_stsfree ( stat ) ;
      return ptr ;
    }

    else {
  
/*
 * Handle first case insert
 */
 
      if ( comp ( ptr->piece, piece ) > 0 ) {
    
        if ( ( ptr = ( gal_piece_t * ) malloc ( sizeof ( gal_piece_t ) ) ) == NULL ) {
          gal_stsfree ( stat ) ;
          gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
          return NULL ;
        }
      
        ptr->next = launch->piece ;
        launch->piece = ptr ;
      
      }
      else {
      
/*
 * Handle generic cases
 */
     
        while ( ptr->next != NULL && comp ( ptr->next->piece, piece ) < 0 ) {
          ptr = ptr->next ;
        }
    
        if ( ptr->next != NULL && comp ( ptr->next->piece, piece ) == 0 ) {
          gal_stsfree ( stat ) ;
          return ptr->next ;
        }
    
        lptr = ptr ;
  
        if ( ( ptr = ( gal_piece_t * ) malloc ( sizeof ( gal_piece_t ) ) ) == NULL ) {
          gal_stsfree ( stat ) ;
          gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
          return NULL ;
        }
    
        ptr->next = lptr->next ;
        lptr->next = ptr ;
      
      }
    
    }
    
  }
  
/*
 * Common stuff
 */
 
  strcpy ( ptr->piece, piece ) ; 
  
  ptr->satnum = satnum ;
  
  if ( objcat->maxsatnum < satnum ) {
    objcat->maxsatnum = satnum ;
  }
  
  if ( objcat->index != NULL ) {
    free ( objcat->index ) ;
    objcat->index = NULL ;
  }  

  strcpy ( ptr->intldesg, intldesg ) ;
  strcpy ( ptr->name, "" ) ;
  ptr->launch_date1 = 0.0 ;
  ptr->launch_date2 = 0.0 ;
  ptr->status = GAL_COS_GEOCENTRIC_ORBIT ;
  ptr->payload = 1 ;
  ptr->decay_date1 = 0.0 ;
  ptr->decay_date2 = 0.0 ;
  ptr->period = 0.0 ;
  ptr->inclo = 0.0 ;
  ptr->apogee = 0.0 ;
  ptr->perigee = 0.0 ;
  ptr->rcs = 0.0 ;
  ptr->owner_code = GAL_COO_UNKNOWN ;
  ptr->tle = NULL ;
  ptr->tcount = 0 ;
  ptr->tag = 1 ;
  ptr->central_body = GAL_OBJ_EARTH ;
  launch->pcount++ ;
  
  gal_stsfree ( stat ) ;
  
  return ptr ;
      
/*  
 * Finished.  
 */  
  
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
