/*  
 *  - - - - - - - - - - - - - -
 *   g a l _ p i e c e _ i n s
 *  - - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine inserts a piece of launch into an object catalog.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *objcat           gal_objcat_t    Pointer to object catalog
 *     satnum                 i          US Strategic Command Object number
 *     *intldesg             c[]         International Designator (COSPAR/WDC-A-R&S)
 *
 *  Returned:  
 * 
 *     *year                  i          Year of launch
 *     *number                i          Number of launch within year 
 *     *status           gal_status_t    Pointer to status structure
 *     *gal_piece_ins    gal_piece_t     Pointer to piece of launch 
 *                                       structure, NULL if failure
 * 
 *  Notes:
 *
 *  1) If the piece of launch is already in the catalog then a pointer
 *     is returned to the existing structure. i.e. no duplicates
 *     are created.
 *
 *  2) If an internal error occurs then the error code
 *     GAL_ALLOC_FAILED is set and the routine returns NULL.
 *
 *  3) The piece launches are stored in a linked list within the
 *     catalog, the order is A, B, ... AA, BB, ... AAA, AAB, ...
 *
 *  4) The international Designator must be in the format.
 *
 *          "YYYY-NNNPPP" e.g. "1997-051VX "
 * 
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsalloc          Create status structure
 *     gal_stsfree           Free status structure
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_fscan             Decode FORTRAN string
 *     gal_launch_ins        Insert launch into catalog
 *     gal_trimr             Trim whitespace from right of string
 *     gal_justl             Justify string in field to left
 *
 *  This revision:  
 * 
 *     2010 February 27 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 February 27 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_PIECE_INS_H_  
#define _GAL_PIECE_INS_H_ 1  

#include "gal_usstratcom.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

gal_piece_t *
gal_piece_ins
(
  gal_objcat_t *objcat,
  int          satnum,
  char         *intldesg,
  int          *year,
  int          *number,
  gal_status_t *status
) ;  

__END_DECLS  

#endif /* !_GAL_PIECE_INS_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
