/*  
 *  - - - - - - - - - - - - -
 *   g a l _ s e t t l e   
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine sets up a TLE structure from given mean Keplerian
 *     elememts suitable for use with the SGP4 propagator.
 *  
 *  Status: 
 *  
 *     Support routine  
 *  
 *  Given:  
 *
 *     epoch1             d         Epoch date 1 ( see Note 1 )
 *     epoch2             d         Epoch date 2 ( see Note 1 )
 *     mean             d[6]        Mean elements ( see Note 2 )
 *  
 *  Returned:  
 *  
 *     *tle           gal_tle_t     TLE structure 
 *     *status       gal_status_t   Pointer to initialized status structure
 *
 *  Notes:
 *
 *  1) The epoch epoch1+epoch2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            epoch1       epoch2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable. The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution. The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 *
 *  2) The elements are stored as follows:
 *
 *     [0] - Argument of perigee ( degrees )
 *     [1] - Right ascension of ascending node ( degrees )
 *     [2] - Inclination ( degrees )
 *     [3] - Mean Motion ( rev / day )
 *     [4] - Eccentricity
 *     [5] - Mean anomaly ( degrees )  
 *
 *  Called:
 *
 *     gal_jd2days                  Convert Julian date to year and day count
 * 
 *  This revision:  
 * 
 *     2010 February 8 Paul Willmott Changed to use GAL status recording
 *                                   mechanism.
 *
 *  Revision History:
 *
 *     2010 January 30 Paul Willmott Unused parameter gm removed.
 *
 *     2009 January 17 Paul Willmott Baseline
 *  
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include "gal_settle.h"
#include "gal_jd2days.h"
#include "gal_status.h"

void
gal_settle
(
  double epoch1,
  double epoch2,
  double mean[6],
  gal_tle_t *tle,
  gal_status_t *status
) 

{

/*
 * Macro for error handler
 */
 
#define ERROR( errno ) \
if ( stat == NULL ) { \
  gal_stsfree ( stat ) ; \
} \
gal_errset ( __FILE__, __LINE__, ( errno), status ) ; \
return

  gal_status_t *stat = NULL ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Clear return status
 */
 
  gal_stsinit ( status ) ;
  
/*
 * Create status structure for calls
 */
 
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    ERROR ( GAL_ALLOC_FAILED ) ;
  }
  
  gal_jd2days ( epoch1, epoch2, &tle->epochyr, &tle->epochdays, stat ) ;
  if ( gal_errc ( stat ) ) {
    gal_stsadd ( stat, status ) ;
    ERROR ( GAL_STSADD_BREAKPOINT ) ;
  }
  
  tle->ndot  = 0.0 ; /* Not used by SGP4 */
  tle->nddot = 0.0 ; /* Not used by SGP4 */
  tle->ephtype = 1 ; /* Not used by SGP4 */
  tle->inclo   = mean[2] ;
  tle->nodeo   = mean[1] ;
  tle->ecco    = mean[4] ;
  tle->argpo   = mean[0] ;
  tle->mo      = mean[5] ;
  tle->no      = mean[3] ;

/*
 * Tidy-up
 */
 
  gal_stsfree ( stat ) ;
  
/*  
 * Finished.  
 */  

}
  
/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
