/*  
 *  - - - - - - - - -
 *   g a l _ s g p 4
 *  - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine is the SGP4 prediction model from Space Command. This is an
 *     updated and combined version of SGP4 and SDP4, which were originally
 *     published separately in Spacetrack Report #3. This version follows the
 *     methodology from the AIAA paper (2006) describing the history and
 *     development of the code.
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     *sgp4        gal_sgp4_t      Initialised structure from gal_sgp4init call.
 *     date1           d            UTC date part 1 (Note 1)  
 *     date2           d            UTC date part 2 (Note 1)  
 *  
 *  Returned:  
 *  
 *     *sgp4        gal_sgp4_t      Common values for subsequent calls
 *     pv            d[2][3]        Geocentric position/velocity (m, m/sec)
 *     *status     gal_status_t     Pointer to initialized status structure
 *
 *  Notes:  
 *  
 *  1) This routine is a translation from c++ to c of David Vallado's SGP4UNIT.sgp4 
 *     routine ( 2007 November 16 ). 
 *
 *  2) The UTC date date1+date2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *             date1        date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable. The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution. The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 * 
 *  Called:
 *
 *     gal_dpper        
 *     gal_dspace
 *     gal_stsinit                       Initialize status structure
 *     gal_errset                        Set error code
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980
 *     Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986
 *     Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  This revision:  
 * 
 *     2010 February 7 
 *  
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SGP4_H_  
#define _GAL_SGP4_H_ 1  

#include "gal_status_t.h"

#include "gal_gm.h"
#include "gal_sgp4t.h"
#include "gal_sgp4init.h"
#include "gal_sgp4rs.h"
#include "gal_tlechksum.h"
#include "gal_tledec.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void 
gal_sgp4
(
  gal_sgp4_t *sgp4,
  double date1,
  double date2,
  double pv[2][3],
  gal_status_t *status
) ; 
   
__END_DECLS  
  
#endif /* !_GAL_SGP4_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009, 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
