/*  
 *  - - - - - - - - - - - 
 *   g a l _ s g p 4 g m  
 *  - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine gets the gravity model parameters required by SGP4
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     *gm           gal_gm_t       Pointer to gravity model structure
 *  
 *  Returned:  
 *  
 *     *tumin           d           Minutes in one time unit
 *     *mu              d           Earth gravitational parameter
 *     *re              d           Radius of the earth in km
 *     *xke             d           Reciprocal of tumin
 *     *j2              d           Un-normalized second zonal harmonic value 
 *     *j3              d           Un-normalized third  zonal harmonic value 
 *     *j4              d           Un-normalized fourth zonal harmonic value
 *     *j3oj2           d           j3 divided by j2
 *     *status     gal_status_t     Pointer to status instance
 * 
 *  Notes:
 *
 *  1) The spherical harmonics of the gravity model passed must be normalized. 
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980, Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986, Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  Called:  
 * 
 *     gal_gmuzh                    Calculate un-normalized zonal harmonic 
 *     gal_facexp_alloc             Allocate factorial exponent lookup table
 *     gal_facexp_free              Deallocate factorial exponent lookup table
 *     gal_stsalloc                 Create status structure
 *     gal_stsfree                  Free status structure
 *     gal_stsadd                   Merge status structures
 *     gal_errset                   Set error code
 *     gal_errc                     Get error count
 *
 *  This revision:  
 *
 *     2014 February 1 Paul Willmott Formatting updated.
 *
 *  Revision History:
 * 
 *     2010 May 1 Paul Willmott General tidy-up and better error handling
 *
 *     2010 February 7 Paul Willmott Baseline
 *  
 *  Copyright (C) 2008-2014 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SGP4GM_H_  
#define _GAL_SGP4GM_H_ 1  

#include "gal_gm.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void
gal_sgp4gm
(
  gal_gm_t *gm,
  double *tumin,
  double *mu,
  double *re,
  double *xke,
  double *j2,
  double *j3,
  double *j4,
  double *j3oj2,
  gal_status_t *status
) ;
  
__END_DECLS  
  
#endif /* !_GAL_SGP4GM_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008-2014 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
