/*  
 *  - - - - - - - - - - - - -
 *   g a l _ s g p 4 i n i t  
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine initializes the variables for gal_sgp4.
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     *gm           gal_gm_t       Gravity Model
 *     *tle          gal_tle_t      TLE parameters
 *  
 *  Returned:  
 *  
 *     *sgp4        gal_sgp4_t      Common values for subsequent calls
 *     *status     gal_status_t     Pointer to initialized status structure
 *
 *  Notes:  
 *  
 *  1) This routine is based on a translation from c++ to c of 
 *     David Vallado's SGP4UNIT.sgp4init routine ( 2007 November 16 ). 
 *
 *  Called:
 *
 *     gal_sgp4gm                  Get gravity model parameters for SGP4
 *     gal_initsgp4p               Initialize SGP4 propagator
 *     gal_dscom        
 *     gal_dpper        
 *     gal_dsinit    
 *     gal_sgp4                    SGP4 orbit propagator
 *     gal_days2cal                Convert day of year to calendar date
 *     gal_cal2jd                  Convert calendar date to Julian Date
 *     gal_errset                  Set error code
 *     gal_stsalloc                Create status structure
 *     gal_stsfree                 Free status structure
 *     gal_errc                    Get error count
 *     gal_stsadd                  Merge status structures
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980, Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986, Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  This revision:  
 * 
 *     2014 February 1 Paul Willmott Formatting updated.
 * 
 *  Revision History:
 *
 *     2010 February 7 Paul Willmott Changed to use GAL status recording
 *     mechanism.
 * 
 *     2010 January 30 Paul Willmott Updated for change in gal_initsgp4p.
 * 
 *     2010 January 10 Paul Willmott Missing #include "gal_sgp4gm.h",
 *     "gal_initsgp4p.h", "gal_dscom.h", "gal_dpper.h", "gal_dsinit.h",
 *     "gal_sgp4.h" added. Typo in #include <string.h> corrected.
 * 
 *     2008 April 6 Paul Willmott Baseline
 * 
 *  Copyright (C) 2008-2014 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SGP4INIT_H_  
#define _GAL_SGP4INIT_H_ 1  

#include "gal_gm.h"
#include "gal_sgp4t.h"
#include "gal_usstratcom.h"
#include "gal_status_t.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void
gal_sgp4init
(
  gal_gm_t *gm,
  gal_tle_t *tle,
  gal_sgp4_t *sgp4,
  gal_status_t *status
) ; 
   
__END_DECLS  
  
#endif /* !_GAL_SGP4INIT_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008-2014 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
