/*  
 *  - - - - - - - - - - - 
 *   g a l _ s g p 4 r s  
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine computes the rise and set parameters
 *     for an Earth orbiting spacecraft and terrestrial
 *     observer using the Ernandes algorithm and the SGP4 propagtor
 *  
 *  Status: 
 *  
 *     Support routine  
 *  
 *  Given:  
 *
 *     utc1             d           UTC date part 1 ( see Note 1 )
 *     utc2             d           UTC date part 2 ( see Note 1 )
 *     latitude         d           Observer latitude ( radians )
 *     longitude        d           Observer longitude ( radians )
 *     height           d           Observer height ASL ( meters )
 *     minel            d           Minimum elevation ( radians )
 *     timefwd          d           Max time forward ( days )
 *     gm               d           Gravitational parameter
 *     re               d           Earth equatorial radius ( meters )
 *     ff               d           Earth flattening factor
 *     *sgp4        gal_sgp4_t      Initialised SGP4 structure
 *  
 *  Returned:  
 *  
 *     pass           d[3][3]       AOS, CUL, & LOS details ( see Note 2 ) 
 *     *status     gal_status_t     Pointer to initialized status structure
 *
 *  Notes:
 *
 *  1) The date utc1+utc2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(UTC)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *              utc1         utc2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 *
 *  2) The rise and set parameters are the time, elevation, and azimuth
 *     for Aquisition of Signal (AOS), Loss of Signal (LOS), and 
 *     Culmination (maximum elevation). On return the array pass 
 *     is populated as follows:
 *
 *         pass[0][0] - AOS JD ( UTC ) date+time
 *         pass[0][1] - AOS Elevation ( radians )
 *         pass[0][2] - AOS Azimuth   ( radians )
 *         pass[1][0] - CUL JD ( UTC ) date+time
 *         pass[1][1] - CUL Elevation ( radians )
 *         pass[1][2] - CUL Azimuth   ( radians )
 *         pass[2][0] - LOS JD ( UTC ) date+time
 *         pass[2][1] - LOS Elevation ( radians )
 *         pass[2][2] - LOS Azimuth   ( radians )
 *
 *  3) This routine is based upon the rise/set algorithm devised
 *     and developed by Ernandes. 
 *  
 *  Called:
 *
 *     gal_anp          Normalise angle into the range 0 <= a < 2pi
 *     gal_anpm         Normalise angle into the range -pi <= a < pi
 *     gal_sgp4         SGP4 propagator
 *     gal_gmst82       Greenwich Mean Sidereal Time IAU 1982
 *     gal_pm           p-vector modulus
 *     gal_pn           p-vector modulus and normalise
 *     gal_rxp          r-matrix, p-vector product
 *     gal_pmp          p-vector subtraction
 *     gal_pdp          p-vector dot product
 *     gal_gd2gce       latitude & longitude to ITRF
 *     gal_pvm          pv-vector modulus 
 *     gal_me2bf        Transform from mean equator to body fixed frame 
 *     gal_sezm         Form SEZ transformation matrix
 *     gal_errset       Set error code
 *     gal_stsalloc     Create status structure
 *     gal_stsfree      Free status structure
 *     gal_stsinit      Initialize status structure
 *     gal_stsadd       Merge status structures
 *  
 *  References:
 *
 *     Kenneth J. Ernandes, private communication, December 17, 1997
 *
 *  This revision:  
 * 
 *     2014 February 2 Paul Willmott Formatting updated. Changed from 
 *     using inverse flattening to flatenning factor.
 * 
 *  Revision History:
 * 
 *     2010 February 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2009-2014 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <math.h>
#include "gal_sgp4rs.h"
#include "gal_math_macros.h"
#include "gal_anp.h"
#include "gal_anpm.h"
#include "gal_sgp4.h"
#include "gal_gmst82.h"
#include "gal_pm.h"
#include "gal_pn.h"
#include "gal_rxp.h"
#include "gal_pmp.h"
#include "gal_pdp.h"
#include "gal_pxp.h"
#include "gal_gd2gce.h"
#include "gal_pvm.h"
#include "gal_me2bf.h"
#include "gal_sezm.h"
#include "gal_status.h"

/* ------------------------------------------------------------------------------ */

/*
 * Computes topocentric look angles corresponding to an input satellite
 * position and velocity, realtive to a ground site location.
 */

void 
lookangle
(
  double slantrange[3],
  double sez[3][3], 
  double *el,
  double *az 
) ;

void 
lookangle
(
  double slantrange[3],
  double sez[3][3], 
  double *el,
  double *az 
)

{

  double sel, rho[3] ;

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Transform the slant range into sez coordinates
 */
 
  gal_rxp ( sez, slantrange, rho ) ;
    
/*
 * Compute Azimuth
 */
 
  *az = atan2 ( rho[1], -rho[0] ) ;
    
/*
 * Ensure the sine of the elevation is in bounds
 */
 
  sel = rho[2] / gal_pm ( slantrange ) ;
  if ( fabs ( sel ) > 1.0 ) {
    sel = sel / fabs ( sel ) ;
  }
    
/*
 * Compute Elevation
 */
 
  *el = asin ( sel ) ;

/*  
 * Finished.  
 */  

}

/* ------------------------------------------------------------------------------ */

void
propagate
(
  double utc,
  gal_sgp4_t *sgp4,
  double obs[3], 
  double efg[2][3],
  double slantrange[3],
  double *srmag,
  double slantrangehat[3],
  gal_status_t *status
) ;

void
propagate
(
  double utc,
  gal_sgp4_t *sgp4,
  double obs[3], 
  double efg[2][3],
  double slantrange[3],
  double *srmag,
  double slantrangehat[3],
  gal_status_t *status
)

{

#define omega ( 7.292115146706979e-05 ) /* Earth Rotation Rate, radians/sec */

/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

/*
 * Propagate orbit and derive results
 */
 
  gal_sgp4 ( sgp4, utc, 0.0 , sgp4->pv, status ) ; 
  gal_pvm ( sgp4->pv, &sgp4->pos, &sgp4->vel ) ; 
  sgp4->time = utc ;
  gal_me2bf ( sgp4->pv, gal_gmst82 ( sgp4->time, 0.0 ), omega, efg ) ;
  gal_pmp ( efg[0], obs, slantrange ) ;
  gal_pn ( slantrange, srmag, slantrangehat ) ;

/*  
 * Finished.  
 */  
    
}

/* ------------------------------------------------------------------------------ */

void
aoslos
( 
  double obs[3],
  double sez[3][3],
  double boresight[3],
  double sminel,
  double ccha, 
  double pass[3][3],
  double gm,
  double re,
  gal_sgp4_t *sgp4,
  double *tstart, 
  double *tstop,
  gal_status_t *status
) ;

void
aoslos
( 
  double obs[3],
  double sez[3][3],
  double boresight[3],
  double sminel,
  double ccha, 
  double pass[3][3],
  double gm,
  double re,
  gal_sgp4_t *sgp4,
  double *tstart, 
  double *tstop,
  gal_status_t *status
)

{

  int i, iter, abovehorizon, neverset, converged ;
  double mult, fel, fbs, f, period, tabove, tbelow, time, deltat ;
  double efg[2][3], slantrangehat[3], srmag, sma, slantrange[3], el, az ;

  gal_status_t *stat ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  stat = gal_stsalloc () ;
  
/*
 * Compute Orbital Period
 */
 
  mult = 1.0 ;
  deltat = 0.00694 * sgp4->pos / re ;                             
  sma = 1.0 / ( 2.0 / sgp4->pos - sgp4->vel * sgp4->vel / gm ) ;
  period = GAL_2PI * sqrt ( sma * sma * sma / gm ) ;
    
/*
 * Do AOS first, then LOS
 */
 
  for ( i=0; i < 2; i++) {
    
    mult = -mult ;
    neverset = 0 ;
        
/*
 * Set initial time bounds
 */
 
    if ( i == 0 ) {
      tbelow = pass[1][0] - deltat ;
      tabove = pass[1][0] ;
    }
    else {
      tbelow = pass[1][0] + deltat ;
      tabove = pass[1][0] ;
    }
        
/*
 * Isolate time interval above and below horizon
 */
 
    do {
        
/*
 * Compute data for outer time bound
 */
   
      propagate ( tbelow, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
      gal_stsadd ( stat, status ) ;
      deltat = 0.00694 * sgp4->pos / re ;
            
/*
 * Determine if outer time bound is below the horizon
 */
 
      fel = gal_pdp ( slantrangehat, sez[2] ) - sminel ;
      fbs = gal_pdp ( slantrangehat, boresight ) - ccha ;
      f = ( fel < fbs ) ? ( fel ) : ( fbs ) ;         

      abovehorizon = f > 0.0 ;
            
/*
 * Isolate a time interval over which the satellite is above and below the horizon
 */
 
      if ( abovehorizon ) {
            
        tabove = tbelow ;
        tbelow += mult * deltat ;
                
/*
 * Stop searching if we move at least one rev outside edge of interval
 */
 
        neverset = ( tbelow <= *tstart - period ) || ( tbelow >= *tstop + period ) ;
                
      }
            
    } while ( abovehorizon && !neverset ) ;
        
/*
 * Isolate the time at the horizon
 */
 
    iter = 0 ;
        
    if ( neverset ) {

      time = ( i != 0 ) ? ( *tstop ) : ( *tstart ) ;         
      propagate ( time, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
      gal_stsadd ( stat, status ) ;
      
    }
    else {
        
      do {
      
        iter++ ;
                
/*
 * Bisect the current interval
 */
 
        time = 0.5 * ( tabove + tbelow ) ;
                
        propagate ( time, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
        gal_stsadd ( stat, status ) ;
        
        fel = gal_pdp ( slantrangehat, sez[2] ) - sminel ;
        fbs = gal_pdp ( slantrangehat, boresight ) - ccha ;
        f = ( fel < fbs ) ? ( fel ) : ( fbs ) ;         
       
        converged = ( fabs ( f ) < 0.000001 ) || ( fabs ( tbelow - tabove ) < 0.00000579 ) || ( iter >= 25 ) ;
                
/*
 * Narrow down time bounds
 */
 
        if ( !converged ) {
          if ( f < 0.0 ) {
             tbelow = time ;
          }
          else {
             tabove = time ;
          }

        }
                
                
      } while ( !converged ) ;
            
    }
        
/*
 * Compute Look Angle
 */
 
    lookangle ( slantrange, sez, &el, &az ) ;
        
/*
 * Set data in structure
 */
   
    if ( i == 0 ) {
      pass[0][0] = time ;
      pass[0][1] = el ;
      pass[0][2] = az ;
    }
    else {
      pass[2][0] = time ;
      pass[2][1] = el ;
      pass[2][2] = az ;
    }
        
  }

  gal_stsfree ( stat ) ;
  
/*  
 * Finished.  
 */  
    
}

/* ------------------------------------------------------------------------------ */

void
gal_sgp4rs
(
  double utc1,
  double utc2,
  double latitude,
  double longitude,
  double height,
  double minel,
  double timefwd,
  double gm,
  double re,
  double ff,
  gal_sgp4_t *sgp4,
  double pass[3][3],
  gal_status_t *status
) 
  
{

  int pfound, iter, converged, i ;
  double f, fprev, time, tprev, tstart, tstop, tbegin, tend, tmid ; 
  double efg[2][3], slantrangehat[3], slanthatdot[3], slantrange[3], srmag, slantrangerate ;
  double obs[3], sez[3][3], boresight[3], sminel, cha, ccha ;

  gal_status_t *stat ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;

  stat = gal_stsalloc () ;
  
/*
 * Compute efg geocentric position of station
 */
 
  gal_gd2gce ( re, ff, longitude, latitude, height, obs, stat ) ;
  gal_stsadd ( stat, status ) ;

/*
 * Compute South, East, Zenith (sez) coordinate frame transformation matrix
 */
 
  gal_sezm ( latitude, longitude, sez ) ; 
            
/*
 * Compute boresight unit vector -- note that this is forced to local
 * vertical for mechanical trackers
 */
 
  boresight[0] = sez[2][0] ; 
  boresight[1] = sez[2][1] ; 
  boresight[2] = sez[2][2] ; 

  sminel = sin ( minel ) ;
  cha = GAL_PI * 0.5 - minel ;
  ccha = cos ( cha ) ;

/*
 * Compute satellite position and velocity in efg coordinates
   and compute Slant Range parameters
 */
 
  propagate ( utc1+utc2, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  slantrangerate = gal_pdp ( efg[1], slantrangehat ) ;
  for ( i=0; i<3; i++ ) {
    slanthatdot[i] = ( efg[1][i] - slantrangerate * slantrangehat[i] ) / srmag ;
  }

/*
 * Save satellite time
 */
 
  time = sgp4->time ;
  tstart = time ;
  tstop = time + timefwd ;
  pfound = 0 ;
    
/*
 * Compute boresight closure rate
 */
 
  f = gal_pdp ( boresight, slanthatdot ) ;
    
  do {
        
    tprev = time ;
    fprev = f ;
        
/*
 * Update time
 */
 
    time = time + 0.00694 * sgp4->pos / re ;
    if (time > tstop) {
      time = tstop ;
    }
    
/*
 * Compute satellite position and velocity in efg coordinates
   and compute Slant Range parameters
 */
 
    propagate ( time, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
    gal_stsadd ( stat, status ) ;
    
    slantrangerate = gal_pdp ( efg[1], slantrangehat ) ;
    for ( i=0; i<3; i++ ) {
      slanthatdot[i] = ( efg[1][i] - slantrangerate * slantrangehat[i] ) / srmag ;
    }

/*
 * Compute boresight closure rate
 */
 
    f = gal_pdp ( boresight, slanthatdot ) ;

/*
 * Check if maximum elevation is isolated
 */
 
    if ( fprev >= 0.0 && f <= 0.0) {
        
      tbegin = tprev ;
      tend = time ;
            
      iter = 0 ;
            
/*
 * Compute pass culmination time
 */
 
      do {
        
        iter++ ;
                
/*
 * Bisect current time interval
 */
 
        pass[1][0] = 0.5 * ( tbegin + tend ) ;
                
/*
 * Compute satellite position and velocity in efg coordinates
   and compute Slant Range parameters
 */
 
        propagate ( pass[1][0], sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
        gal_stsadd ( stat, status ) ;
        
        slantrangerate = gal_pdp ( efg[1], slantrangehat ) ;
        for ( i=0; i<3; i++ ) {
          slanthatdot[i] = ( efg[1][i] - slantrangerate * slantrangehat[i] ) / srmag ;
        }

/*
 * Compute boresight closure rate
 */
 
        f = gal_pdp ( boresight, slanthatdot ) ;

/*
 * Convergence check -- low "F", half second, or iter limit
 */
 
        converged = ( fabs ( f ) <= 0.000001 ) || ( fabs ( pass[1][0] - tbegin ) < 0.00000579 ) || ( 25 <= iter ) ;
                
/*
 * Determine new interval bounds
 */
 
        if ( !converged ) {
          if ( f > 0.0 ) {
            tbegin = pass[1][0] ;
          }
          else {
            tend = pass[1][0] ;
          }
        }
                
      } while ( !converged ) ;
            
/*
 * See if satellite is above minimum elevation at culmination time
 */
 
      pfound = ( gal_pdp ( slantrangehat, sez[2] ) > sminel ) && ( gal_pdp ( slantrangehat, boresight ) > ccha ) ;
            
/*
 * Proceed if valid pass
 */
 
      if ( pfound ) {
            
/*
 * Compute the culmination azimuth & Elevation
 */
 
        lookangle ( slantrange, sez, &pass[1][1], &pass[1][2] ) ;
                
/*
 * Find the AOS and LOS data
 */
 
        aoslos ( obs, sez, boresight, sminel, ccha, pass, gm, re, sgp4, &tstart, &tstop, stat ) ;
        gal_stsadd ( stat, status ) ;
        
      }
            
    }
        
  } while ( !pfound && tstop > time) ;
    
/*
 * If pass was not found, check if satellite is above horizon at mid interval
 */
 
  if ( !pfound ) {
    
    tmid = 0.5 * (tstart + tstop) ;
        
    propagate ( tmid, sgp4, obs, efg, slantrange, &srmag, slantrangehat, stat ) ;
    gal_stsadd ( stat, status ) ;
    
/*
 * Set pfound = -1 if we're "always" above the horizon
 */
 
    if ( gal_pdp ( slantrangehat, sez[2] ) > sminel && gal_pdp ( slantrangehat, boresight ) > ccha ) {
        
      gal_warnset ( __FILE__, __LINE__, GAL_NEVER_SETS, status ) ;
            
      pass[1][0] = tmid ;
      lookangle ( slantrange, sez, &pass[1][1], &pass[1][2] ) ;
            
/*
 * Find the AOS and LOS Data
 */
 
      aoslos ( obs, sez, boresight, sminel, ccha, pass, gm, re, sgp4, &tstart, &tstop, stat ) ;
      gal_stsadd ( stat, status ) ;
      
    }
        
  }

/*
 * Normalise angles
 */
     
  pass[0][1] = gal_anpm ( pass[0][1] ) ;
  pass[0][2] = gal_anp  ( pass[0][2] ) ;
  pass[1][1] = gal_anpm ( pass[1][1] ) ;
  pass[1][2] = gal_anp  ( pass[1][2] ) ;
  pass[2][1] = gal_anpm ( pass[2][1] ) ;
  pass[2][2] = gal_anp  ( pass[2][2] ) ;
      
  gal_stsfree ( stat ) ;
  
/*  
 * Finished.  
 */  
    
}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009-2014 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
