/*  
 *  - - - - - - - - - - - 
 *   g a l _ s g p 4 r s  
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine computes the rise and set parameters
 *     for an Earth orbiting spacecraft and terrestrial
 *     observer using the Ernandes algorithm and the SGP4 propagtor
 *  
 *  Status: 
 *  
 *     Support routine  
 *  
 *  Given:  
 *
 *     utc1             d           UTC date part 1 ( see Note 1 )
 *     utc2             d           UTC date part 2 ( see Note 1 )
 *     latitude         d           Observer latitude ( radians )
 *     longitude        d           Observer longitude ( radians )
 *     height           d           Observer height ASL ( meters )
 *     minel            d           Minimum elevation ( radians )
 *     timefwd          d           Max time forward ( days )
 *     gm               d           Gravitational parameter
 *     re               d           Earth equatorial radius ( meters )
 *     ff               d           Earth flattening factor
 *     *sgp4        gal_sgp4_t      Initialised SGP4 structure
 *  
 *  Returned:  
 *  
 *     pass           d[3][3]       AOS, CUL, & LOS details ( see Note 2 ) 
 *     *status     gal_status_t     Pointer to initialized status structure
 *
 *  Notes:
 *
 *  1) The date utc1+utc2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(UTC)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *              utc1         utc2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 *
 *  2) The rise and set parameters are the time, elevation, and azimuth
 *     for Aquisition of Signal (AOS), Loss of Signal (LOS), and 
 *     Culmination (maximum elevation). On return the array pass 
 *     is populated as follows:
 *
 *         pass[0][0] - AOS JD ( UTC ) date+time
 *         pass[0][1] - AOS Elevation ( radians )
 *         pass[0][2] - AOS Azimuth   ( radians )
 *         pass[1][0] - CUL JD ( UTC ) date+time
 *         pass[1][1] - CUL Elevation ( radians )
 *         pass[1][2] - CUL Azimuth   ( radians )
 *         pass[2][0] - LOS JD ( UTC ) date+time
 *         pass[2][1] - LOS Elevation ( radians )
 *         pass[2][2] - LOS Azimuth   ( radians )
 *
 *  3) This routine is based upon the rise/set algorithm devised
 *     and developed by Ernandes. 
 *  
 *  Called:
 *
 *     gal_anp          Normalise angle into the range 0 <= a < 2pi
 *     gal_anpm         Normalise angle into the range -pi <= a < pi
 *     gal_sgp4         SGP4 propagator
 *     gal_gmst82       Greenwich Mean Sidereal Time IAU 1982
 *     gal_pm           p-vector modulus
 *     gal_pn           p-vector modulus and normalise
 *     gal_rxp          r-matrix, p-vector product
 *     gal_pmp          p-vector subtraction
 *     gal_pdp          p-vector dot product
 *     gal_gd2gce       latitude & longitude to ITRF
 *     gal_pvm          pv-vector modulus 
 *     gal_me2bf        Transform from mean equator to body fixed frame 
 *     gal_sezm         Form SEZ transformation matrix
 *     gal_errset       Set error code
 *     gal_stsalloc     Create status structure
 *     gal_stsfree      Free status structure
 *     gal_stsinit      Initialize status structure
 *     gal_stsadd       Merge status structures
 *  
 *  References:
 *
 *     Kenneth J. Ernandes, private communication, December 17, 1997
 *
 *  This revision:  
 * 
 *     2014 February 2 Paul Willmott Formatting updated. Changed from 
 *     using inverse flattening to flatenning factor.
 * 
 *  Revision History:
 * 
 *     2010 February 7 Paul Willmott Baseline
 * 
 *  Copyright (C) 2009-2014 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SGP4RS_H_  
#define _GAL_SGP4RS_H_ 1  

#include "gal_sgp4t.h"
#include "gal_status_t.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void
gal_sgp4rs
(
  double utc1,
  double utc2,
  double latitude,
  double longitude,
  double height,
  double minel,
  double timefwd,
  double gm,
  double re,
  double ff,
  gal_sgp4_t *sgp4,
  double pass[3][3],
  gal_status_t *status
) ;
 
__END_DECLS  
  
#endif /* !_GAL_SGP4RS_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009-2014 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
