/*  
 *  - - - - - - - - - - - 
 *   g a l _ t l e e n c  
 *  - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine encodes data from tle structure into packed two line element cards
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *tle         gal_tle_t       Unpacked data
 *  
 *  Returned:  
 *  
 *     *card1         c[70]         First Card
 *     *card2         c[70]         Second Card
 *     *status     gal_status_t     Pointer to status structure
 *  
 *  Notes:
 *
 *  1) Standard Two-Line Elements (TLE) Format
 *     
 *     1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1321
 *     2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 23251
 *     
 *     Breakdown of a Two Line Element Set
 *     
 *     !>Line Number 1
 *     !   !>Catalog Number (NORAD)
 *     !   !  !>Security Classification for this Element Set
 *     !   !  !    !>International Identification for this Object (COSPAR)
 *     !   !  !    !     !>Two Digit Year
 *     !   !  !    !     !  !>Day of Year
 *     !   !  !    !     !  !     !>Fraction of 24 Hour Day
 *     !   !  !    !     !  !     !     !>Sign of 1st Time Derivative
 *     !   !  !    !     !  !     !     !    !>1st Time Derivative
 *     !   !  !    !     !  !     !     !    !     !>Sign of 2nd Time Derivative
 *     !   !  !    !     !  !     !     !    !     !  !>2nd Time Derivative
 *     !   !  !    !     !  !     !     !    !     !  !  !>Sign of exponent
 *     !   !  !    !     !  !     !     !    !     !  !   !>Exponent 2ndTimeDerivative
 *     !   !  !    !     !  !     !     !    !     !  !     !>Sign of BSTAR drag term
 *     !   !  !    !     !  !     !     !    !     !  !     !  !>BSTAR/Drag Term
 *     !   !  !    !     !  !     !     !    !     !  !     !  !  !>Sign of Exponent
 *     !   !  !    !     !  !     !     !    !     !  !     !  !  !!>Exponent BstarDrg
 *     !   !  !    !     !  !     !     !    !     !  !     !  !  !! !>Ephemeris Type
 *     !   !  !    !     ! ---    !     !    !     !  !     !  !  !! ! !>Element No.
 *     ! -----! -------- --|||--------- !--------- !-----   !-----!! ! ----!>Checksum
 *     1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1321 = Line 1
 *     2 25107 086.3970 282.3520 0003565 065.4476 294.7132 14.34205441 23251 = Line 2
 *     123456789012345678901234567890123456789012345678901234567890123456789 = columns
 *     ! ----- ---.---- ---.---- ------- ---.---- ---.---- --.--------|||||!>Checksum
 *     !   !   Incl     RAAN     Ecc     AoP      MA       RpD        -----
 *     !   !   !        !        !       !        !        !          !>Rev # @ Epoch
 *     !   !   !        !        !       !        !        !>MeanMotion(Revolutions/Day)
 *     !   !   !        !        !       !        !>Mean Anomaly
 *     !   !   !        !        !       !>Argument of Perigee
 *     !   !   !        !        !>Eccentricity, with assumed decimal point leading
 *     !   !   !        !>Right Ascension of Ascending Node
 *     !   !   !>Inclination
 *     !   !>Catalog Number (NORAD)
 *     !>Line Number 2
 *     
 *     Line 1
 *     
 *        Column Numbers     Number of
 *        First     Last     Characters     Description
 *        -----     ----     ----------     -----------
 *          1        1           1          Line No. Identification
 *          3        7           5          Catalog No.
 *          8        8           1          Security Classification
 *         10       17           8          International Designator (COSPAR/WDC-A-R&S)
 *         19       32          14          YRDOY.FODddddd
 *         34       34           1          Sign of first time derivative
 *         35       43           9          1st Time Derative
 *         45       45           1          Sign of 2nd Time Derivative
 *         46       50           5          2nd Time Derivative
 *         51       51           1          Sign of 2nd Time Derivative Exponent
 *         52       52           1          Exponent of 2nd Time Derivative
 *         54       54           1          Sign of Bstar/Drag Term
 *         55       59           5          Bstar/Drag Term
 *         60       60           1          Sign of Exponent of Bstar/Drag Term
 *         61       61           1          Exponent of Bstar/Drag Term
 *         63       63           1          Ephemeris Type
 *         65       68           4          Element Number
 *         69       69           1          Check Sum, Modulo 10
 *
 *   "1 25107U 97082D   98151.26839894 -.00007632  00000-0 -27359-2 0  1321"
 *    XYXXXXXYXYYYYYYYYXYYXXXXXXXXXXXXYXXXXXXXXXXYXXXXXXXXYXXXXXXXXYXYXXXXY
 *   "CX1I5CX1A8X1I2D12.8X1D10.8X1E8.0X1E8.5X1I1X1I4I1"
 *     
 *     Line 2
 *     
 *        Column Numbers     Number of
 *        First     Last     Characters     Description
 *        -----     ----     ----------     -----------
 *          1        1           1          Line No. Identification
 *          3        7           5          Catalog No.
 *          9       16           8          Inclination
 *         18       25           8          Right Ascension of Ascending Node
 *         27       33           7          Eccentricity with assumed leading decimal
 *         35       42           8          Argument of the Perigee
 *         44       51           8          Mean Anomaly
 *         53       63          11          Revolutions per Day (Mean Motion)
 *         64       68           5          Revolution Number at Epoch
 *         69       69           1          Check Sum Modulo 10
 *
 *   "2 25107  86.3970 282.3520 0003565  65.4476 294.7132 14.34205441 23251"
 *    XYXXXXXYXXXXXXXXYXXXXXXXXYXXXXXXXYXXXXXXXXYXXXXXXXXYXXXXXXXXXXXYYYYYY
 *   "CX1I5X1D8.4X1D8.4X1D7.7X1D8.4X1D8.4X1D11.8I5I1"
 *
 *  2) Checksum (Modulo 10)
 *     (Letters, blanks, periods, plus signs = 0; minus signs = 1)
 *     
 *  Called:
 *
 *     gal_tlechksum                        Calculate NORAD TLE checksum character
 *     gal_delete                           Delete sub-string
 *     gal_stsinit                          Initialize status structure
 *     gal_errset                           Set error code
 *     gal_padl                             Pad string on left with spaces
 *     gal_rightstr                         Get right sub-string
 *
 *  References:
 *  
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *  
 *  This revision:  
 * 
 *     2010 March 20 Paul Willmott Baseline.
 *
 *  Revision History:
 *
 *     2010 March 20 Paul Willmott Baseline.
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include <string.h>
#include "gal_tleenc.h"
#include "gal_pstrings.h"
#include "gal_status.h"
#include "gal_tlechksum.h"
  
void
gal_tleenc
(
  gal_tle_t *tle,
  char *card1,
  char *card2,
  gal_status_t *status 
) 

{
  
  char satnum[256], c1[256], c2[256], nddot[70] ;
   
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  if ( tle == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_NULL_POINTER, status ) ;
    return ;
  }
  
/*
 * Encode Card 1
 */
                                                          

  sprintf ( satnum, "00000%i", tle->satnum ) ;
  gal_rightstr ( satnum, satnum, 5 ) ; 
  
  if ( tle->nddot == 0.0 ) {
    strcpy ( nddot, " 00000-0" ) ;
  }
  else {
    sprintf ( nddot, "%9.4e", tle->nddot ) ;
    gal_delete ( nddot, 1, 1 ) ;
    gal_delete ( nddot, 5, 1 ) ;
    gal_delete ( nddot, 6, 1 ) ;
    gal_padl ( nddot, nddot, 8 ) ;
  }
  
  sprintf ( c1, "1 %5s%1c %-8s %i%12.8f %11.8f %8s %11.4e %1i %4i", 
            satnum,
            tle->classification,
            tle->intldesg,
            tle->epochyr, 
            tle->epochdays,
            tle->ndot,
            nddot,
            tle->bstar,
            tle->ephtype,
            tle->setnum
  ) ;      

  gal_delete ( c1,  9, 2 ) ;
  gal_delete ( c1, 11, 1 ) ;
          
  gal_delete ( c1, 18, 2 ) ;
  gal_delete ( c1, 34, 1 ) ;
  
  gal_delete ( c1, 55, 1 ) ;
  gal_delete ( c1, 59, 1 ) ;
  gal_delete ( c1, 60, 1 ) ; 
  
  if ( c1[20] == ' ' ) {
    c1[20] = '0' ;
  }     
  
  if ( c1[60] != '0' ) {
    c1[60]-- ;
  }
  
  if ( tle->nddot != 0.0 ) {
    c1[51] += 4 ;
  }

  c1[68] = gal_tlechksum ( c1 ) ;
  c1[69] = '\0' ;     
    
/*
 * Encode Card 2
 */
                                               
  sprintf ( c2, "2 %5s %8.4f %8.4f %8.7f %8.4f %8.4f %11.8f%5i", 
            satnum,
            tle->inclo,
            tle->nodeo,
            tle->ecco, 
            tle->argpo, 
            tle->mo, 
            tle->no,
            tle->revnum
          ) ;

  gal_delete ( c2, 26, 2 ) ;

  c2[68] = gal_tlechksum ( c2 ) ;
  c2[69] = '\0' ;     

  strcpy ( card1, c1 ) ;
  strcpy ( card2, c2 ) ;  
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
