/*  
 *  - - - - - - - - - - - -
 *   g a l _ t l e g e t n
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine finds a TLE set for the piece of launch with
 *     the specified USSTRATCOM Object Number.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *objcat       gal_objcat_t    Pointer to Object Catlog
 *     satnum             i          USSTRATCOM Object Number for the
 *                                   piece of launch 
 *     date1              d          UTC date part 1 ( see Note 1 )
 *     date2              d          UTC date part 2 ( see Note 1 ) 
 *     condx              i          Search conditions ( see Note 2 )
 *  
 *  Returned:  
 *  
 *     *status       gal_status_t    Pointer to status structure
 *     *gal_tlegetn   gal_tle_t      Pointer to TLE structure, 
 *                                   NULL if failure
 *
 *  Notes:
 *
 *  1) The UTC date DATE1+DATE2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *             DATE1        DATE2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable. The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution. The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 *
 *  2) Search conditions:
 *
 *     GAL_LT              return first TLE less than DATE1+DATE2
 *     GAL_LTE             return first TLE less than or equal to DATE1+DATE2
 *     GAL_GT              return first TLE greater than DATE1+DATE2
 *     GAL_GTE             return first TLE greater than or equal to DATE1+DATE2
 *     GAL_EQ              return TLE equal to DATE1+DATE2
 *     GAL_LATEST          return most recent TLE
 *     GAL_EARLIEST        return earliest TLE
 *
 *  3) This routine will build an index to the object catalog if
 *     one does not already exist. So the first execution will be 
 *     slower than subsequent calls.
 *
 *  4) If a TLE cannot be found that match the search conditions then
 *     the error code GAL_NOT_FOUND is set and the routine returns
 *     NULL.
 * 
 *  Called:
 *
 *     gal_stsinit         Initialize status structure
 *     gal_stsalloc        Create status structure
 *     gal_stsfree         Free status structure
 *     gal_stsadd          Merge status structures
 *     gal_errset          Set error code
 *     gal_getpiecen       Get piece of launch by USSTRATCOM Object Number
 *     gal_tlegetp         Get TLE for piece of launch
 * 
 *  This revision:  
 * 
 *     2010 March 25 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 25 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_tlegetn.h"
#include "gal_status.h"
#include "gal_getpiecen.h"
#include "gal_tlegetp.h"

gal_tle_t *
gal_tlegetn
(
  gal_objcat_t *objcat,
  int satnum,
  double date1,
  double date2,
  int condx,
  gal_status_t *status
)  

{


  gal_piece_t *piece ;
  
  gal_status_t *stat ;
  
  gal_tle_t *tle ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }
  
/*
 * Try and find piece of launch
 */
 
  piece = gal_getpiecen ( objcat, satnum, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  if ( piece == NULL ) {
    gal_stsfree ( stat ) ;
    gal_errset ( __FILE__, __LINE__, GAL_NOT_FOUND, status ) ;
    return NULL ;
  }
  
/*
 * Try and find TLE
 */
 
  tle = gal_tlegetp ( piece, date1, date2, condx, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  gal_stsfree ( stat ) ;
  
  return tle ;
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
