/*  
 *  - - - - - - - - - - - -
 *   g a l _ t l e g e t p
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine finds a TLE set for selected piece of launch.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:
 *
 *     *piece          gal_piece_t   Pointer to selected piece of launch
 *     date1                d        UTC date part 1 ( see Note 1 )
 *     date2                d        UTC date part 2 ( see Note 1 ) 
 *     condx                i        Search conditions ( see Note 2 )
 *  
 *  Returned:  
 *  
 *     *status         gal_status_t  Pointer to status structure
 *     *gal_tlegetp     gal_tle_t    Pointer to TLE structure, 
 *                                   NULL if failure
 *
 *  Notes:
 *
 *  1) The UTC date DATE1+DATE2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *             DATE1        DATE2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable. The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution. The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed. 
 *
 *  2) Search conditions:
 *
 *     GAL_LT              return first TLE less than DATE1+DATE2
 *     GAL_LTE             return first TLE less than or equal to DATE1+DATE2
 *     GAL_GT              return first TLE greater than DATE1+DATE2
 *     GAL_GTE             return first TLE greater than or equal to DATE1+DATE2
 *     GAL_EQ              return TLE equal to DATE1+DATE2
 *     GAL_LATEST          return most recent TLE
 *     GAL_EARLIEST        return earliest TLE
 *
 *  3) If a TLE cannot be found that match the search conditions then
 *     the error code GAL_NOT_FOUND is set and the routine returns
 *     NULL.
 * 
 *  Called:
 *
 *     gal_stsinit         Initialize status structure
 *     gal_errset          Set error code
 * 
 *  This revision:  
 * 
 *     2013 August 5 Paul Willmott gal_datenorm removed.
 *  
 *  Revision History:
 *
 *     2010 March 21 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012, 2013 Paul C. L. Willmott. 
 *  See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_TLEGETP_H_  
#define _GAL_TLEGETP_H_ 1  

#include "gal_usstratcom.h"

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif

__BEGIN_DECLS  

gal_tle_t *
gal_tlegetp
(
  gal_piece_t *piece,
  double date1,
  double date2,
  int condx,
  gal_status_t *status
) ;

__END_DECLS  

#endif /* !_GAL_TLEGETP_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012, 2013 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
