/*  
 *  - - - - - - - - - - - 
 *   g a l _ t l e i n s
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine inserts a two-line-element set into an object catalog.
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *
 *  Given:
 *
 *     *objcat           gal_objcat_t    Pointer to object catalog
 *     *card1                c[]         Pointer to Card 1
 *     *card2                c[]         Pointer to Card 2
 *
 *  Returned:  
 * 
 *     *status           gal_status_t    Pointer to status structure
 *     *gal_tleins         gal_tle_t     Pointer to TLE structure, 
 *                                       NULL if failure
 * 
 *  Notes:
 *
 *  1) If the TLE is already in the catalog then a pointer
 *     is returned to the existing structure. i.e. no duplicates
 *     are created.
 *
 *  2) If an internal error occurs then the error code
 *     GAL_ALLOC_FAILED is set and the routine returns NULL.
 *
 *  3) TLEs are stored in a linked list within the
 *     catalog, the order most recent first 
 *
 *  Called:
 *
 *     gal_stsinit           Initialize status structure
 *     gal_errset            Set error code
 *     gal_stsalloc          Create status structure
 *     gal_stsfree           Free status structure
 *     gal_stsadd            Merge status structures
 *     gal_errc              Get error count
 *     gal_piece_ins         Insert piece of launch
 *     gal_tledec            Decode TLE
 *
 *  This revision:  
 * 
 *     2010 March 14 Paul Willmott Baseline
 *  
 *  Revision History:
 *
 *     2010 March 14 Paul Willmott Baseline
 * 
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include <stdlib.h>
#include "gal_tleins.h"
#include "gal_status.h"
#include "gal_tledec.h"
#include "gal_piece_ins.h"

int 
comp_tle
(
  gal_tle_t *ptr,
  gal_tle_t *tle
)

{
      
  if ( ( ptr->epochyr < tle->epochyr ) ||
       ( ptr->epochyr == tle->epochyr && ptr->epochdays < tle->epochdays ) ||
       ( ptr->epochyr == tle->epochyr && ptr->epochdays == tle->epochdays && ptr->setnum < tle->setnum )
     ) {
    return 1 ;
  }
  else   if ( ( ptr->epochyr > tle->epochyr ) ||
       ( ptr->epochyr == tle->epochyr && ptr->epochdays > tle->epochdays ) ||
       ( ptr->epochyr == tle->epochyr && ptr->epochdays == tle->epochdays && ptr->setnum > tle->setnum )
     ) {
    return -1 ; 
  }
  else {
    return 0 ;
  }

  
}

gal_tle_t *
gal_tleins
(
  gal_objcat_t *objcat,
  char *card1,
  char *card2,
  gal_status_t *status
) 

{

  gal_status_t *stat ;
  
  gal_tle_t *tle, *ptr ;
  
  gal_piece_t *piece ;
  
  int year, number ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  gal_stsinit ( status ) ;
  
  stat = gal_stsalloc () ;
  if ( stat == NULL ) {
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }
  
/*
 * Decode Cards 1 & 2
 */
 
  tle = ( gal_tle_t * ) malloc ( sizeof ( gal_tle_t ) ) ;
  if ( tle == NULL ) {
    gal_stsfree ( stat ) ;
    gal_errset ( __FILE__, __LINE__, GAL_ALLOC_FAILED, status ) ;
    return NULL ;
  }
  
  gal_tledec ( card1, card2, tle, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  if ( gal_errc ( status ) ) {
    free ( tle ) ;
    gal_stsfree ( stat ) ;
    return NULL ;
  }

/*
 * Find or create piece of launch, and by implication launch
 */
 
  piece = gal_piece_ins ( objcat, tle->satnum, tle->intldesg, &year, &number, stat ) ;
  gal_stsadd ( stat, status ) ;
  
  if ( piece == NULL ) {
    free ( tle ) ;
    gal_stsfree ( stat ) ;
    return NULL ;
  }
  
/*
 * --------------------
 * Find insertion point
 * --------------------
 */

/*
 * Handle empty list case
 */
 
  if ( piece->tle == NULL ) {
  
    piece->tle = tle ;
    tle->next = NULL ;
    
  }
  else {
  
/*
 * Handle First case equal, existing is retained if date and set num match but data different
 */
   
    ptr = piece->tle ;
    
    if ( comp_tle ( ptr, tle ) == 0 ) {
         
      free ( tle ) ;
      gal_stsfree ( stat ) ;
      return ptr ;
      
    }

    else {
  
/*
 * Handle first case insert
 */
 
      if ( comp_tle ( ptr, tle ) > 0 ) {
          
        tle->next = piece->tle ;
        piece->tle = tle ;
      
      }
      else {
      
/*
 * Handle generic cases
 */
     
        while ( ptr->next != NULL && comp_tle ( ptr->next, tle ) < 0 ) {
          ptr = ptr->next ;
        }
    
        if ( ptr->next != NULL && comp_tle ( ptr->next, tle ) == 0 ) {
          free ( tle ) ;
          gal_stsfree ( stat ) ;
          return ptr->next ;
        }
    
        tle->next = ptr->next ;
        ptr->next = tle ;
      
      }
    
    }
    
  }  
  
  gal_stsfree ( stat ) ;
    
  return tle ;
    
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
