/*  
 *  - - - - - - - - - - - - - - - - -
 *   g a l _ u s s t r a t c o m . h
 *  - - - - - - - - - - - - - - - - - 
 *  
 *  This header file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This header file includes all of the component header files
 *     for the US Strategic Command sub-library, and defines the 
 *     object catalog structures, and constants.
 *  
 *  Status: 
 *  
 *     Sub-library header file  
 *
 *  Includes:  
 *
 *     gal_launch_ins.h         Insert launch into object catalog
 *     gal_ldssr.h              Load Satellite Situation Report
 *     gal_lvcode.h             Get launch vehicle code
 *     gal_lvname.h             Get launch vehicle name
 *     gal_objcat_alloc.h       Create object catalog
 *     gal_objcat_export.h      Export object catalog
 *     gal_objcat_free.h        Free object catalog
 *     gal_objcat_init.h        Initialize object catalog
 *     gal_objowner_code.h      Get object owner code
 *     gal_objowner_name.h      Get object owner name
 *     gal_osc2mean.h           Convert osculating to mean elements
 *     gal_piece_ins.h          Insert piece of launch into object catalog
 *     gal_settle.h             Set TLE values
 *     gal_sgp4.h               SGP4 propagator
 *     gal_sgp4gm.h             Set SGP4 gravity parameters
 *     gal_sgp4init.h           Initialize SGP4 propagator
 *     gal_sgp4rs.h             Satellite rise/set calculator
 *     gal_sgp4t.h              Defines SGP4 workspace structures
 *     gal_tlechksum.h          Calculate TLE checksum
 *     gal_tledec.h             Decode TLEs
 *     gal_tleins.h             Insert TLE into object catalog
 *     gal_getlaunch.h          Find launch in object catalog
 *     gal_getpiece.h           Find piece of launch in object catalog
 *     gal_ldtle.h              Load TLEs from ASCII file
 *     gal_tleenc.h             Encode TLEs
 *     gal_svtle.h              Save TLEs to ASCII file
 *     gal_objcat_index.h       Create USSTRATCOM Object Number index
 *     gal_getpiecen.h          Get piece of launch by object number
 *     gal_tlegetp.h            Get TLEs for specified piece of launch
 *     gal_tleget.h             Get TLEs for piece of launch specified by 
 *                              International Designation
 *     gal_tlegetn              Get TLEs for piece of launch specified by
 *                              USSTRATCOM Object Number
 *     gal_objcat_import        Import object catalog
 *
 *  This revision:  
 * 
 *     2010 April 11 Paul Willmott central_body field added to piece of launch.
 *
 *  Revision History:
 *
 *     2010 March 25 Paul Willmott gal_tleget, gal_tlegetn, gal_objcat_import
 *                                 added.
 *
 *     2010 March 21 Paul Willmott gal_objcat_index, gal_getpiecen,
 *                                 gal_tlegetp added.
 *
 *     2010 March 20 Paul Willmott gal_tleenc and gal_svtle added.
 *
 *     2010 March 14 Paul Willmott gal_tleins added.
 *
 *     2010 March 13 Paul Willmott Baseline.
 *  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_USSTRATCOM_H_  
#define _GAL_USSTRATCOM_H_ 1  

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

/* 
 * Two-Line Element Structure
 */
  
struct tle_node {
  int             satnum         ; /* US Strategic Command Object Number          */
  char            classification ; /* Security Classification                     */
  char            intldesg[12]   ; /* International Designator (COSPAR/WDC-A-R&S) */
  int             epochyr        ; /* Epoch Year                                  */
  double          epochdays      ; /* Epoch Day of Year (plus Fraction)           */
  double          date1          ; /* UTC date part 1 - normalized                */
  double          date2          ; /* UTC date part 2 - normalized                */
  double          ndot           ; /* Mean motion derivative (rev/day /2)         */
  double          nddot          ; /* Mean motion second derivative (rev/day2 /6) */
  double          bstar          ; /* Bstar / Drag Term                           */
  int             ephtype        ; /* Ephermeris Type                             */
  int             setnum         ; /* Element set number                          */
  double          inclo          ; /* Inclination                                 */
  double          nodeo          ; /* Right Ascension of Ascending Node (deg)     */
  double          ecco           ; /* Eccentricity                                */
  double          argpo          ; /* Argument of Perigee (deg)                   */
  double          mo             ; /* Mean Anamaly (deg)                          */
  double          no             ; /* Mean Motion (rev/day)                       */
  int             revnum         ; /* Epoch Revolution Number                     */
  struct tle_node *next          ; /* Pointer to next TLE                         */
} ;

typedef struct tle_node gal_tle_t ;

/*
 * Piece of launch definition structure
 */
 
struct piece_node {
  char              piece[4]     ; /* Piece of launch                             */
  int               satnum       ; /* US Strategic Command Object Number          */
  char              intldesg[12] ; /* International Designator (COSPAR/WDC-A-R&S) */
  char              name[40]     ; /* Description of piece of launch              */
  double            launch_date1 ; /* Launch date part 1                          */
  double            launch_date2 ; /* Launch date part 2                          */
  int               status       ; /* Orbital Status                              */
  double            decay_date1  ; /* Decay date part 1                           */
  double            decay_date2  ; /* Decay date part 2                           */
  double            period       ; /* Period                                      */
  double            inclo        ; /* Inclination                                 */
  double            apogee       ; /* Apogee                                      */
  double            perigee      ; /* Perigee                                     */
  double            rcs          ; /* RADAR cross section                         */
  int               owner_code   ; /* GAL Catalog Object Owner Code               */
  int               payload      ; /* Payload = 1, Debris = 0                     */
  gal_tle_t         *tle         ; /* Pointer to TLE list                         */
  int               tcount       ; /* Number of TLEs                              */
  int               tag          ; /* Tag; 1 = tagged, 0 = not tagged             */
  int               central_body ; /* Central body object identifier              */
  struct piece_node *next        ; /* Pointer to next piece of launch             */
} ;

typedef struct piece_node gal_piece_t ;

#define GAL_LOADALL    (0)
#define GAL_LOADTAGGED (1)

#define GAL_SAVEALL    (0)
#define GAL_SAVETAGGED (1)

#define GAL_LT         (0)         /* return first TLE less than DATE1+DATE2                */
#define GAL_LTE        (1)         /* return first TLE less than or equal to DATE1+DATE2    */
#define GAL_GT         (2)         /* return first TLE greater than DATE1+DATE2             */
#define GAL_GTE        (3)         /* return first TLE greater than or equal to DATE1+DATE2 */
#define GAL_EQ         (4)         /* return TLE equal to DATE1+DATE2                       */
#define GAL_LATEST     (5)         /* return most recent TLE                                */
#define GAL_EARLIEST   (6)         /* return earliest TLE                                   */

/*
 * Launch definition structure
 */
 
struct launch_node {
  int                year         ; /* Year of launch                              */
  int                number       ; /* Launch number of year                       */
  double             launch_date1 ; /* Date of launch part 1                       */
  double             launch_date2 ; /* Date of launch part 2                       */
  int                lv_code      ; /* GAL Launch Vehicle Code                     */
  gal_piece_t        *piece       ; /* Pointer to pieces of launch                 */
  int                pcount       ; /* Number of pieces of launch                  */
  struct launch_node *next        ; /* Pointer to next launch                      */
} ;

typedef struct launch_node gal_launch_t ;

/*
 * Object catalog structure
 */
 
typedef struct {
  gal_launch_t *launch           ; /* Pointer to launches                         */
  gal_piece_t  **index           ; /* Pointer to pointer lookup table             */
  int          maxsatnum         ; /* Largest USSTRATCOM Object Number            */
} gal_objcat_t ;

/* ---------------------------
 * Catalog Object Status Codes
 * ---------------------------
 */

enum {
  GAL_COS_UNKNOWN               =  0, /* Unknown Status */
  GAL_COS_BARYCENTRIC_ORBIT_EMB =  1,       
  GAL_COS_CIRCUMLUNAR           =  2,                           
  GAL_COS_DECAYED               =  3,
  GAL_COS_ESCAPED_SOLAR_SYSTEM  =  4,                  
  GAL_COS_GEOCENTRIC_ORBIT      =  5,
  GAL_COS_HELIOCENTRIC_ORBIT    =  6,              
  GAL_COS_LUNAR_IMPACT          =  7,                          
  GAL_COS_LUNAR_LANDING         =  8,                         
  GAL_COS_MARS_IMPACT           =  9,                           
  GAL_COS_MARS_ORBIT            = 10,                            
  GAL_COS_NO_ELEMENTS_AVAILABLE = 11,               
  GAL_COS_NO_INITIAL_ELEMENTS   = 12,                   
  GAL_COS_SELENOCENTRIC_ORBIT   = 13,            
  GAL_COS_VENUS_IMPACT          = 14,                          
  GAL_COS_VENUS_LANDING         = 15,                         
  GAL_COS_VENUS_ORBIT           = 16
} ;

/* --------------------------
 * Catalog Object Owner Codes
 * --------------------------
 */
 
enum {
  GAL_COO_UNKNOWN               =  0, 
  GAL_COO_ALGERIA               =  1,
  GAL_COO_ARABSAT               =  2,
  GAL_COO_ARGENTINA             =  3,
  GAL_COO_ASIASAT_CORP          =  4,
  GAL_COO_AUSTRALIA             =  5,
  GAL_COO_BERMUDA               =  6,
  GAL_COO_BRAZIL                =  7,
  GAL_COO_CANADA                =  8,
  GAL_COO_CHILE                 =  9,
  GAL_COO_CIS                   = 10,
  GAL_COO_COLUMBIA              = 11,
  GAL_COO_CZECHOSLOVAKIA        = 12,
  GAL_COO_DENMARK               = 13,
  GAL_COO_EGYPT                 = 14,
  GAL_COO_ESA                   = 15,
  GAL_COO_ESRO                  = 16,
  GAL_COO_EUMETSAT              = 17,
  GAL_COO_EUTELSAT              = 18,
  GAL_COO_FRANCE                = 19,
  GAL_COO_FRANCE_GERMANY        = 20,
  GAL_COO_GERMANY               = 21,
  GAL_COO_GLOBALSTAR            = 22,
  GAL_COO_GREECE                = 23,
  GAL_COO_INDIA                 = 24,
  GAL_COO_INDONESIA             = 25,
  GAL_COO_INMARSAT              = 26,
  GAL_COO_INTELSAT              = 27,
  GAL_COO_IRAN                  = 28,
  GAL_COO_IRIDIUM               = 29,
  GAL_COO_ISRAEL                = 30,
  GAL_COO_ISRO                  = 31,
  GAL_COO_ISS                   = 32,
  GAL_COO_ITALY                 = 33,
  GAL_COO_JAPAN                 = 34,
  GAL_COO_KOREA                 = 35,
  GAL_COO_LUXEMBOURG            = 36,
  GAL_COO_MALAYSIA              = 37,
  GAL_COO_MEXICO                = 38,
  GAL_COO_NATO                  = 39,
  GAL_COO_NETHERLANDS           = 40,
  GAL_COO_NEW_ICO               = 41,
  GAL_COO_NIGERIA               = 42,
  GAL_COO_NORTH_KOREA           = 43,
  GAL_COO_NORWAY                = 44,
  GAL_COO_PAKISTAN              = 45,
  GAL_COO_PHILIPPINES           = 46,
  GAL_COO_PORTUGAL              = 47,
  GAL_COO_PRC                   = 48,
  GAL_COO_PRC_BRAZIL            = 49,
  GAL_COO_PRC_ESA               = 50,
  GAL_COO_RASC                  = 51, /* Need to find out what this is */
  GAL_COO_SAUDI_ARABIA          = 52,
  GAL_COO_SEA_LAUNCH            = 53,
  GAL_COO_SINGPORE_TAIWAN       = 54,
  GAL_COO_SOUTH_AFRICA          = 55,
  GAL_COO_SOUTH_KOREA           = 56,
  GAL_COO_SPAIN                 = 57,
  GAL_COO_SWEDEN                = 58,
  GAL_COO_SWITZERLAND           = 59,
  GAL_COO_TAIWAN                = 60,
  GAL_COO_THAILAND              = 61,
  GAL_COO_TURKEY                = 62,
  GAL_COO_UNITED_ARAB_EMIRATES  = 63,
  GAL_COO_UNITED_KINGDOM        = 64,
  GAL_COO_USA                   = 65,
  GAL_COO_USA_BRAZIL            = 66,
  GAL_COO_VENEZUELA             = 67,
  GAL_COO_VIETNAM               = 68
} ;

#define GAL_MAX_OWNERS ( GAL_COO_VIETNAM + 1 )

/* --------------------------
 * Launch vehicle identifiers
 * --------------------------
 */

enum {
    GAL_LV_UNKNOWN                                  = 0,  
    GAL_LV_APEX                                     = 1,  
    GAL_LV_ARIANE_1                                 = 2,  
    GAL_LV_ARIANE_2                                 = 3,  
    GAL_LV_ARIANE_3                                 = 4,  
    GAL_LV_ARIANE_40                                = 5,  
    GAL_LV_ARIANE_40PLUS                            = 6,  
    GAL_LV_ARIANE_40PLUS3                           = 7,  
    GAL_LV_ARIANE_42L                               = 8,  
    GAL_LV_ARIANE_42LPLUS3                          = 9,  
    GAL_LV_ARIANE_42P                               = 10,  
    GAL_LV_ARIANE_42PPLUS                           = 11,  
    GAL_LV_ARIANE_42PPLUS3                          = 12,  
    GAL_LV_ARIANE_44L                               = 13,  
    GAL_LV_ARIANE_44LPLUS                           = 14,  
    GAL_LV_ARIANE_44LPLUS3                          = 15,  
    GAL_LV_ARIANE_44LP                              = 16,  
    GAL_LV_ARIANE_44LPPLUS                          = 17,  
    GAL_LV_ARIANE_44LPPLUS3                         = 18,  
    GAL_LV_ARIANE_44P                               = 19,  
    GAL_LV_ARIANE_44PPUS3                           = 20,  
    GAL_LV_ARIANE_5                                 = 21,  
    GAL_LV_ASLV_D3                                  = 22,  
    GAL_LV_ASLV_D4                                  = 23,  
    GAL_LV_ATHENA_1_OAM                             = 24,  
    GAL_LV_ATHENA_2                                 = 25,  
    GAL_LV_ATLAS                                    = 26,  
    GAL_LV_ATLAS_1_CENTAUR                          = 27,  
    GAL_LV_ATLAS_14E                                = 28,  
    GAL_LV_ATLAS_2_CENTAUR                          = 29,  
    GAL_LV_ATLAS_28E                                = 30,  
    GAL_LV_ATLAS_2A                                 = 31,  
    GAL_LV_ATLAS_2A_CENTAUR                         = 32,  
    GAL_LV_ATLAS_2AS_CENTAUR                        = 33,  
    GAL_LV_ATLAS_34F                                = 34,  
    GAL_LV_ATLAS_35F                                = 35,  
    GAL_LV_ATLAS_3A_CENTAUR                         = 36,  
    GAL_LV_ATLAS_3B_CENTAUR                         = 37,  
    GAL_LV_ATLAS_41E                                = 38,  
    GAL_LV_ATLAS_42E                                = 39,  
    GAL_LV_ATLAS_5_CENTAUR                          = 40,  
    GAL_LV_ATLAS_5_STAR_48_B                        = 41,  
    GAL_LV_ATLAS_55E                                = 42,  
    GAL_LV_ATLAS_67F                                = 43,  
    GAL_LV_ATLAS_75E                                = 44,  
    GAL_LV_ATLAS_AGENA                              = 45,  
    GAL_LV_ATLAS_AGENA_A                            = 46,  
    GAL_LV_ATLAS_AGENA_B                            = 47,  
    GAL_LV_ATLAS_AGENA_D                            = 48,  
    GAL_LV_ATLAS_CENTAUR                            = 49,  
    GAL_LV_ATLAS_CENTAUR_2                          = 50,  
    GAL_LV_ATLAS_D                                  = 51,  
    GAL_LV_ATLAS_D_5                                = 52,  
    GAL_LV_ATLAS_D_7                                = 53,  
    GAL_LV_ATLAS_F                                  = 54,  
    GAL_LV_ATLAS_F_BURNER_2                         = 55,  
    GAL_LV_ATLAS_H                                  = 56,  
    GAL_LV_BLACK_ARROW                              = 57,  
    GAL_LV_BLOCK_DM                                 = 58,  
    GAL_LV_BLOCK_DM_SL                              = 59,  
    GAL_LV_BREEZE_KM                                = 60,  
    GAL_LV_BREEZE_M                                 = 61,  
    GAL_LV_CELESTIS_01_PEGASUS                      = 62,  
    GAL_LV_CELESTIS_02_TAURUS                       = 63,  
    GAL_LV_CELESTIS_03_TAURUS                       = 64,  
    GAL_LV_CZ_1                                     = 65,  
    GAL_LV_CZ_2                                     = 66,  
    GAL_LV_CZ_2B                                    = 67,  
    GAL_LV_CZ_2C                                    = 68,  
    GAL_LV_CZ_2D                                    = 69,  
    GAL_LV_CZ_2E                                    = 70,  
    GAL_LV_CZ_2F                                    = 71,  
    GAL_LV_CZ_3                                     = 72,  
    GAL_LV_CZ_3A                                    = 73,  
    GAL_LV_CZ_3B                                    = 74,  
    GAL_LV_CZ_3C                                    = 75,  
    GAL_LV_CZ_4                                     = 76,  
    GAL_LV_CZ_4B                                    = 77,  
    GAL_LV_CZ_4C                                    = 78,  
    GAL_LV_CZ_5                                     = 79,  
    GAL_LV_DELTA                                    = 80,  
    GAL_LV_DELTA_1                                  = 81,  
    GAL_LV_DELTA_1_PLUSCAMEO                        = 82,  
    GAL_LV_DELTA_1_CEP_1                            = 83,  
    GAL_LV_DELTA_1_ITOS_B                           = 84,  
    GAL_LV_DELTA_2                                  = 85,  
    GAL_LV_DELTA_2_DUVE                             = 86,  
    GAL_LV_DELTA_3                                  = 87,  
    GAL_LV_DELTA_4                                  = 88,  
    GAL_LV_DELTA_4H                                 = 89,  
    GAL_LV_DIAMANT                                  = 90,  
    GAL_LV_DIAMANT_MIKA                             = 91,  
    GAL_LV_DIAMANT_B                                = 92,  
    GAL_LV_DIAMANT_B_P4                             = 93,  
    GAL_LV_DNEPR_1                                  = 94,  
    GAL_LV_FALCON_1                                 = 95,  
    GAL_LV_FREGAT                                   = 96,  
    GAL_LV_GSLV                                     = 97,  
    GAL_LV_H_1                                      = 98,  
    GAL_LV_H_1_MABES                                = 99,  
    GAL_LV_H_2                                      = 100,  
    GAL_LV_H_2A                                     = 101,  
    GAL_LV_H_2B                                     = 102,  
    GAL_LV_IABS                                     = 103,  
    GAL_LV_IRIS                                     = 104,  
    GAL_LV_IRS_P2                                   = 105,  
    GAL_LV_IUS                                      = 106,  
    GAL_LV_JUNO_II                                  = 107,  
    GAL_LV_M_3C                                     = 108,  
    GAL_LV_M_3H                                     = 109,  
    GAL_LV_M_3S                                     = 110,  
    GAL_LV_M_3S2                                    = 111,  
    GAL_LV_M_4S                                     = 112,  
    GAL_LV_M_5                                      = 113,  
    GAL_LV_MARS_96                                  = 114,  
    GAL_LV_MINOTAUR                                 = 115,  
    GAL_LV_N_1                                      = 116,  
    GAL_LV_N_2                                      = 117,  
    GAL_LV_OPTUS_B1_STAR_63F                        = 118,  
    GAL_LV_PAM_S                                    = 119,  
    GAL_LV_PEGASUS                                  = 120,  
    GAL_LV_PSLV                                     = 121,  
    GAL_LV_PSLV_1C                                  = 122,  
    GAL_LV_SAFIR_2                                  = 123,  
    GAL_LV_SATURN_1                                 = 124,  
    GAL_LV_SATURN_1B                                = 125,  
    GAL_LV_SATURN_5                                 = 126,  
    GAL_LV_SCOUT_A                                  = 127,  
    GAL_LV_SCOUT_A_1                                = 128,  
    GAL_LV_SCOUT_B                                  = 129,  
    GAL_LV_SCOUT_B_1                                = 130,  
    GAL_LV_SCOUT_D_1                                = 131,  
    GAL_LV_SCOUT_D_1_D                              = 132,  
    GAL_LV_SCOUT_E_1                                = 133,  
    GAL_LV_SCOUT_F_1                                = 134,  
    GAL_LV_SCOUT_G_1                                = 135,  
    GAL_LV_SCOUT_X_1                                = 136,  
    GAL_LV_SCOUT_X_2M                               = 137,  
    GAL_LV_SCOUT_X_3                                = 138,  
    GAL_LV_SCOUT_X_3M                               = 139,  
    GAL_LV_SCOUT_X_4                                = 140,  
    GAL_LV_SHAVIT                                   = 141,  
    GAL_LV_SL_04                                    = 142,  
    GAL_LV_SL_1                                     = 143,  
    GAL_LV_SL_11                                    = 144,  
    GAL_LV_SL_12                                    = 145,  
    GAL_LV_SL_13                                    = 146,  
    GAL_LV_SL_14                                    = 147,  
    GAL_LV_SL_16                                    = 148,  
    GAL_LV_SL_18                                    = 149,  
    GAL_LV_SL_19                                    = 150,  
    GAL_LV_SL_21                                    = 151,  
    GAL_LV_SL_23                                    = 152,  
    GAL_LV_SL_24                                    = 153,  
    GAL_LV_SL_26                                    = 154,  
    GAL_LV_SL_3                                     = 155,  
    GAL_LV_SL_4                                     = 156,  
    GAL_LV_SL_5                                     = 157,  
    GAL_LV_SL_6                                     = 158,  
    GAL_LV_SL_7                                     = 159,  
    GAL_LV_SL_8                                     = 160,  
    GAL_LV_SL_9                                     = 161,  
    GAL_LV_SLV_3                                    = 162,  
    GAL_LV_SS_18                                    = 163,  
    GAL_LV_SSN_23                                   = 164,  
    GAL_LV_STRELA                                   = 165,  
    GAL_LV_TAURUS                                   = 166,  
    GAL_LV_THOR_ABLE                                = 167,  
    GAL_LV_THOR_ABLESTAR                            = 168,  
    GAL_LV_THOR_AGENA_B                             = 169,  
    GAL_LV_THOR_AGENA_D                             = 170,  
    GAL_LV_THOR_ALTAIR                              = 171,  
    GAL_LV_THOR_BURNER_2                            = 172,  
    GAL_LV_THOR_BURNER_2A                           = 173,  
    GAL_LV_THOR_DELTA_1                             = 174,  
    GAL_LV_THORAD_AGENA_D                           = 175,  
    GAL_LV_THORAD_DELTA_1                           = 176,  
    GAL_LV_TITAN_2                                  = 177,  
    GAL_LV_TITAN_2G                                 = 178,  
    GAL_LV_TITAN_3                                  = 179,  
    GAL_LV_TITAN_34B                                = 180,  
    GAL_LV_TITAN_34B_AGENA                          = 181,  
    GAL_LV_TITAN_34B_AGENA_D                        = 182,  
    GAL_LV_TITAN_34D                                = 183,  
    GAL_LV_TITAN_34D_AGENA_D                        = 184,  
    GAL_LV_TITAN_34D_IUS                            = 185,  
    GAL_LV_TITAN_3A_TRANSTAGE                       = 186,  
    GAL_LV_TITAN_3B_AGENA                           = 187,  
    GAL_LV_TITAN_3C                                 = 188,  
    GAL_LV_TITAN_3C_TRANSTAGE                       = 189,  
    GAL_LV_TITAN_3D                                 = 190,  
    GAL_LV_TITAN_3E                                 = 191,  
    GAL_LV_TITAN_3E_CENTAUR                         = 192,  
    GAL_LV_TITAN_4                                  = 193,  
    GAL_LV_TITAN_4_CENTAUR                          = 194,  
    GAL_LV_TITAN_401_CENTAUR                        = 195,  
    GAL_LV_TITAN_4A                                 = 196,  
    GAL_LV_TITAN_4A_CENTAUR                         = 197,  
    GAL_LV_TITAN_4B                                 = 198,  
    GAL_LV_TITAN_4B_CENTAUR                         = 199,  
    GAL_LV_TOS                                      = 200,  
    GAL_LV_VANGUARD                                 = 201  
} ;
   
#define GAL_MAX_LAUNCHERS ( GAL_LV_VANGUARD + 1 )

#include "gal_launch_ins.h"
#include "gal_ldssr.h"
#include "gal_lvcode.h"
#include "gal_lvname.h"
#include "gal_objcat_alloc.h"
#include "gal_objcat_export.h"
#include "gal_objcat_free.h"
#include "gal_objcat_init.h"
#include "gal_objowner_code.h"
#include "gal_objowner_name.h"
#include "gal_osc2mean.h"
#include "gal_piece_ins.h"
#include "gal_settle.h"
#include "gal_sgp4.h"
#include "gal_sgp4gm.h"
#include "gal_sgp4init.h"
#include "gal_sgp4rs.h"
#include "gal_sgp4t.h"
#include "gal_tlechksum.h"
#include "gal_tledec.h"
#include "gal_tleins.h"
#include "gal_getlaunch.h"
#include "gal_getpiece.h"
#include "gal_ldtle.h"
#include "gal_tleenc.h"
#include "gal_svtle.h"
#include "gal_objcat_index.h"
#include "gal_getpiecen.h"
#include "gal_tlegetp.h"
#include "gal_tleget.h"
#include "gal_tlegetn.h"
#include "gal_objcat_import.h"

__END_DECLS  

#endif /* !_GAL_USSTRATCOM_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2010, 2011, 2012 Paul C. L. Willmott  
 *
 *  Permission is hereby granted, free of charge, to any person obtaining 
 *  a copy of this software and associated documentation files (the 
 *  "Software"), to deal in the Software without restriction, including 
 *  without limitation the rights to use, copy, modify, merge, publish, 
 *  distribute, sublicense, and/or sell copies of the Software, and to 
 *  permit persons to whom the Software is furnished to do so, subject to 
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included 
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
 *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
 *  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 *  OTHER DEALINGS IN THE SOFTWARE.
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat-bda.org  
 */
